import reflex as rx

class BiAbacus(rx.Component):
    library = "react-icons/bi"
    tag = "BiAbacus"


class BiAccessibility(rx.Component):
    library = "react-icons/bi"
    tag = "BiAccessibility"


class BiAddToQueue(rx.Component):
    library = "react-icons/bi"
    tag = "BiAddToQueue"


class BiAdjust(rx.Component):
    library = "react-icons/bi"
    tag = "BiAdjust"


class BiAlarmAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiAlarmAdd"


class BiAlarmExclamation(rx.Component):
    library = "react-icons/bi"
    tag = "BiAlarmExclamation"


class BiAlarmOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiAlarmOff"


class BiAlarmSnooze(rx.Component):
    library = "react-icons/bi"
    tag = "BiAlarmSnooze"


class BiAlarm(rx.Component):
    library = "react-icons/bi"
    tag = "BiAlarm"


class BiAlbum(rx.Component):
    library = "react-icons/bi"
    tag = "BiAlbum"


class BiAlignJustify(rx.Component):
    library = "react-icons/bi"
    tag = "BiAlignJustify"


class BiAlignLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiAlignLeft"


class BiAlignMiddle(rx.Component):
    library = "react-icons/bi"
    tag = "BiAlignMiddle"


class BiAlignRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiAlignRight"


class BiAnalyse(rx.Component):
    library = "react-icons/bi"
    tag = "BiAnalyse"


class BiAnchor(rx.Component):
    library = "react-icons/bi"
    tag = "BiAnchor"


class BiAngry(rx.Component):
    library = "react-icons/bi"
    tag = "BiAngry"


class BiAperture(rx.Component):
    library = "react-icons/bi"
    tag = "BiAperture"


class BiArch(rx.Component):
    library = "react-icons/bi"
    tag = "BiArch"


class BiArchiveIn(rx.Component):
    library = "react-icons/bi"
    tag = "BiArchiveIn"


class BiArchiveOut(rx.Component):
    library = "react-icons/bi"
    tag = "BiArchiveOut"


class BiArchive(rx.Component):
    library = "react-icons/bi"
    tag = "BiArchive"


class BiArea(rx.Component):
    library = "react-icons/bi"
    tag = "BiArea"


class BiArrowBack(rx.Component):
    library = "react-icons/bi"
    tag = "BiArrowBack"


class BiArrowFromBottom(rx.Component):
    library = "react-icons/bi"
    tag = "BiArrowFromBottom"


class BiArrowFromLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiArrowFromLeft"


class BiArrowFromRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiArrowFromRight"


class BiArrowFromTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiArrowFromTop"


class BiArrowToBottom(rx.Component):
    library = "react-icons/bi"
    tag = "BiArrowToBottom"


class BiArrowToLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiArrowToLeft"


class BiArrowToRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiArrowToRight"


class BiArrowToTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiArrowToTop"


class BiAt(rx.Component):
    library = "react-icons/bi"
    tag = "BiAt"


class BiAtom(rx.Component):
    library = "react-icons/bi"
    tag = "BiAtom"


class BiAward(rx.Component):
    library = "react-icons/bi"
    tag = "BiAward"


class BiBadgeCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiBadgeCheck"


class BiBadge(rx.Component):
    library = "react-icons/bi"
    tag = "BiBadge"


class BiBaguette(rx.Component):
    library = "react-icons/bi"
    tag = "BiBaguette"


class BiBall(rx.Component):
    library = "react-icons/bi"
    tag = "BiBall"


class BiBandAid(rx.Component):
    library = "react-icons/bi"
    tag = "BiBandAid"


class BiBarChartAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiBarChartAlt2"


class BiBarChartAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiBarChartAlt"


class BiBarChartSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiBarChartSquare"


class BiBarChart(rx.Component):
    library = "react-icons/bi"
    tag = "BiBarChart"


class BiBarcodeReader(rx.Component):
    library = "react-icons/bi"
    tag = "BiBarcodeReader"


class BiBarcode(rx.Component):
    library = "react-icons/bi"
    tag = "BiBarcode"


class BiBaseball(rx.Component):
    library = "react-icons/bi"
    tag = "BiBaseball"


class BiBasket(rx.Component):
    library = "react-icons/bi"
    tag = "BiBasket"


class BiBasketball(rx.Component):
    library = "react-icons/bi"
    tag = "BiBasketball"


class BiBath(rx.Component):
    library = "react-icons/bi"
    tag = "BiBath"


class BiBattery(rx.Component):
    library = "react-icons/bi"
    tag = "BiBattery"


class BiBed(rx.Component):
    library = "react-icons/bi"
    tag = "BiBed"


class BiBeenHere(rx.Component):
    library = "react-icons/bi"
    tag = "BiBeenHere"


class BiBeer(rx.Component):
    library = "react-icons/bi"
    tag = "BiBeer"


class BiBellMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiBellMinus"


class BiBellOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiBellOff"


class BiBellPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiBellPlus"


class BiBell(rx.Component):
    library = "react-icons/bi"
    tag = "BiBell"


class BiBible(rx.Component):
    library = "react-icons/bi"
    tag = "BiBible"


class BiBitcoin(rx.Component):
    library = "react-icons/bi"
    tag = "BiBitcoin"


class BiBlanket(rx.Component):
    library = "react-icons/bi"
    tag = "BiBlanket"


class BiBlock(rx.Component):
    library = "react-icons/bi"
    tag = "BiBlock"


class BiBluetooth(rx.Component):
    library = "react-icons/bi"
    tag = "BiBluetooth"


class BiBody(rx.Component):
    library = "react-icons/bi"
    tag = "BiBody"


class BiBold(rx.Component):
    library = "react-icons/bi"
    tag = "BiBold"


class BiBoltCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiBoltCircle"


class BiBomb(rx.Component):
    library = "react-icons/bi"
    tag = "BiBomb"


class BiBone(rx.Component):
    library = "react-icons/bi"
    tag = "BiBone"


class BiBong(rx.Component):
    library = "react-icons/bi"
    tag = "BiBong"


class BiBookAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookAdd"


class BiBookAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookAlt"


class BiBookBookmark(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookBookmark"


class BiBookContent(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookContent"


class BiBookHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookHeart"


class BiBookOpen(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookOpen"


class BiBookReader(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookReader"


class BiBook(rx.Component):
    library = "react-icons/bi"
    tag = "BiBook"


class BiBookmarkAltMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookmarkAltMinus"


class BiBookmarkAltPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookmarkAltPlus"


class BiBookmarkAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookmarkAlt"


class BiBookmarkHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookmarkHeart"


class BiBookmarkMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookmarkMinus"


class BiBookmarkPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookmarkPlus"


class BiBookmark(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookmark"


class BiBookmarks(rx.Component):
    library = "react-icons/bi"
    tag = "BiBookmarks"


class BiBorderAll(rx.Component):
    library = "react-icons/bi"
    tag = "BiBorderAll"


class BiBorderBottom(rx.Component):
    library = "react-icons/bi"
    tag = "BiBorderBottom"


class BiBorderInner(rx.Component):
    library = "react-icons/bi"
    tag = "BiBorderInner"


class BiBorderLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiBorderLeft"


class BiBorderNone(rx.Component):
    library = "react-icons/bi"
    tag = "BiBorderNone"


class BiBorderOuter(rx.Component):
    library = "react-icons/bi"
    tag = "BiBorderOuter"


class BiBorderRadius(rx.Component):
    library = "react-icons/bi"
    tag = "BiBorderRadius"


class BiBorderRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiBorderRight"


class BiBorderTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiBorderTop"


class BiBot(rx.Component):
    library = "react-icons/bi"
    tag = "BiBot"


class BiBowlHot(rx.Component):
    library = "react-icons/bi"
    tag = "BiBowlHot"


class BiBowlRice(rx.Component):
    library = "react-icons/bi"
    tag = "BiBowlRice"


class BiBowlingBall(rx.Component):
    library = "react-icons/bi"
    tag = "BiBowlingBall"


class BiBox(rx.Component):
    library = "react-icons/bi"
    tag = "BiBox"


class BiBracket(rx.Component):
    library = "react-icons/bi"
    tag = "BiBracket"


class BiBraille(rx.Component):
    library = "react-icons/bi"
    tag = "BiBraille"


class BiBrain(rx.Component):
    library = "react-icons/bi"
    tag = "BiBrain"


class BiBriefcaseAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiBriefcaseAlt2"


class BiBriefcaseAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiBriefcaseAlt"


class BiBriefcase(rx.Component):
    library = "react-icons/bi"
    tag = "BiBriefcase"


class BiBrightnessHalf(rx.Component):
    library = "react-icons/bi"
    tag = "BiBrightnessHalf"


class BiBrightness(rx.Component):
    library = "react-icons/bi"
    tag = "BiBrightness"


class BiBroadcast(rx.Component):
    library = "react-icons/bi"
    tag = "BiBroadcast"


class BiBrushAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiBrushAlt"


class BiBrush(rx.Component):
    library = "react-icons/bi"
    tag = "BiBrush"


class BiBugAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiBugAlt"


class BiBug(rx.Component):
    library = "react-icons/bi"
    tag = "BiBug"


class BiBuildingHouse(rx.Component):
    library = "react-icons/bi"
    tag = "BiBuildingHouse"


class BiBuilding(rx.Component):
    library = "react-icons/bi"
    tag = "BiBuilding"


class BiBuildings(rx.Component):
    library = "react-icons/bi"
    tag = "BiBuildings"


class BiBulb(rx.Component):
    library = "react-icons/bi"
    tag = "BiBulb"


class BiBullseye(rx.Component):
    library = "react-icons/bi"
    tag = "BiBullseye"


class BiBuoy(rx.Component):
    library = "react-icons/bi"
    tag = "BiBuoy"


class BiBusSchool(rx.Component):
    library = "react-icons/bi"
    tag = "BiBusSchool"


class BiBus(rx.Component):
    library = "react-icons/bi"
    tag = "BiBus"


class BiCabinet(rx.Component):
    library = "react-icons/bi"
    tag = "BiCabinet"


class BiCableCar(rx.Component):
    library = "react-icons/bi"
    tag = "BiCableCar"


class BiCake(rx.Component):
    library = "react-icons/bi"
    tag = "BiCake"


class BiCalculator(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalculator"


class BiCalendarAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendarAlt"


class BiCalendarCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendarCheck"


class BiCalendarEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendarEdit"


class BiCalendarEvent(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendarEvent"


class BiCalendarExclamation(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendarExclamation"


class BiCalendarHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendarHeart"


class BiCalendarMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendarMinus"


class BiCalendarPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendarPlus"


class BiCalendarStar(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendarStar"


class BiCalendarWeek(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendarWeek"


class BiCalendarX(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendarX"


class BiCalendar(rx.Component):
    library = "react-icons/bi"
    tag = "BiCalendar"


class BiCameraHome(rx.Component):
    library = "react-icons/bi"
    tag = "BiCameraHome"


class BiCameraMovie(rx.Component):
    library = "react-icons/bi"
    tag = "BiCameraMovie"


class BiCameraOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiCameraOff"


class BiCamera(rx.Component):
    library = "react-icons/bi"
    tag = "BiCamera"


class BiCandles(rx.Component):
    library = "react-icons/bi"
    tag = "BiCandles"


class BiCapsule(rx.Component):
    library = "react-icons/bi"
    tag = "BiCapsule"


class BiCaptions(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaptions"


class BiCar(rx.Component):
    library = "react-icons/bi"
    tag = "BiCar"


class BiCard(rx.Component):
    library = "react-icons/bi"
    tag = "BiCard"


class BiCaretDownCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretDownCircle"


class BiCaretDownSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretDownSquare"


class BiCaretDown(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretDown"


class BiCaretLeftCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretLeftCircle"


class BiCaretLeftSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretLeftSquare"


class BiCaretLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretLeft"


class BiCaretRightCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretRightCircle"


class BiCaretRightSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretRightSquare"


class BiCaretRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretRight"


class BiCaretUpCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretUpCircle"


class BiCaretUpSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretUpSquare"


class BiCaretUp(rx.Component):
    library = "react-icons/bi"
    tag = "BiCaretUp"


class BiCarousel(rx.Component):
    library = "react-icons/bi"
    tag = "BiCarousel"


class BiCartAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiCartAdd"


class BiCartAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiCartAlt"


class BiCartDownload(rx.Component):
    library = "react-icons/bi"
    tag = "BiCartDownload"


class BiCart(rx.Component):
    library = "react-icons/bi"
    tag = "BiCart"


class BiCast(rx.Component):
    library = "react-icons/bi"
    tag = "BiCast"


class BiCategoryAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiCategoryAlt"


class BiCategory(rx.Component):
    library = "react-icons/bi"
    tag = "BiCategory"


class BiCctv(rx.Component):
    library = "react-icons/bi"
    tag = "BiCctv"


class BiCertification(rx.Component):
    library = "react-icons/bi"
    tag = "BiCertification"


class BiChair(rx.Component):
    library = "react-icons/bi"
    tag = "BiChair"


class BiChalkboard(rx.Component):
    library = "react-icons/bi"
    tag = "BiChalkboard"


class BiChart(rx.Component):
    library = "react-icons/bi"
    tag = "BiChart"


class BiChat(rx.Component):
    library = "react-icons/bi"
    tag = "BiChat"


class BiCheckCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiCheckCircle"


class BiCheckDouble(rx.Component):
    library = "react-icons/bi"
    tag = "BiCheckDouble"


class BiCheckShield(rx.Component):
    library = "react-icons/bi"
    tag = "BiCheckShield"


class BiCheckSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiCheckSquare"


class BiCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiCheck"


class BiCheckboxChecked(rx.Component):
    library = "react-icons/bi"
    tag = "BiCheckboxChecked"


class BiCheckboxMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiCheckboxMinus"


class BiCheckboxSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiCheckboxSquare"


class BiCheckbox(rx.Component):
    library = "react-icons/bi"
    tag = "BiCheckbox"


class BiCheese(rx.Component):
    library = "react-icons/bi"
    tag = "BiCheese"


class BiChevronDownCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronDownCircle"


class BiChevronDownSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronDownSquare"


class BiChevronDown(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronDown"


class BiChevronLeftCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronLeftCircle"


class BiChevronLeftSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronLeftSquare"


class BiChevronLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronLeft"


class BiChevronRightCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronRightCircle"


class BiChevronRightSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronRightSquare"


class BiChevronRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronRight"


class BiChevronUpCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronUpCircle"


class BiChevronUpSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronUpSquare"


class BiChevronUp(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronUp"


class BiChevronsDown(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronsDown"


class BiChevronsLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronsLeft"


class BiChevronsRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronsRight"


class BiChevronsUp(rx.Component):
    library = "react-icons/bi"
    tag = "BiChevronsUp"


class BiChild(rx.Component):
    library = "react-icons/bi"
    tag = "BiChild"


class BiChip(rx.Component):
    library = "react-icons/bi"
    tag = "BiChip"


class BiChurch(rx.Component):
    library = "react-icons/bi"
    tag = "BiChurch"


class BiCircleHalf(rx.Component):
    library = "react-icons/bi"
    tag = "BiCircleHalf"


class BiCircleQuarter(rx.Component):
    library = "react-icons/bi"
    tag = "BiCircleQuarter"


class BiCircleThreeQuarter(rx.Component):
    library = "react-icons/bi"
    tag = "BiCircleThreeQuarter"


class BiCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiCircle"


class BiClinic(rx.Component):
    library = "react-icons/bi"
    tag = "BiClinic"


class BiClipboard(rx.Component):
    library = "react-icons/bi"
    tag = "BiClipboard"


class BiCloset(rx.Component):
    library = "react-icons/bi"
    tag = "BiCloset"


class BiCloudDownload(rx.Component):
    library = "react-icons/bi"
    tag = "BiCloudDownload"


class BiCloudDrizzle(rx.Component):
    library = "react-icons/bi"
    tag = "BiCloudDrizzle"


class BiCloudLightRain(rx.Component):
    library = "react-icons/bi"
    tag = "BiCloudLightRain"


class BiCloudLightning(rx.Component):
    library = "react-icons/bi"
    tag = "BiCloudLightning"


class BiCloudRain(rx.Component):
    library = "react-icons/bi"
    tag = "BiCloudRain"


class BiCloudSnow(rx.Component):
    library = "react-icons/bi"
    tag = "BiCloudSnow"


class BiCloudUpload(rx.Component):
    library = "react-icons/bi"
    tag = "BiCloudUpload"


class BiCloud(rx.Component):
    library = "react-icons/bi"
    tag = "BiCloud"


class BiCodeAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiCodeAlt"


class BiCodeBlock(rx.Component):
    library = "react-icons/bi"
    tag = "BiCodeBlock"


class BiCodeCurly(rx.Component):
    library = "react-icons/bi"
    tag = "BiCodeCurly"


class BiCode(rx.Component):
    library = "react-icons/bi"
    tag = "BiCode"


class BiCoffeeTogo(rx.Component):
    library = "react-icons/bi"
    tag = "BiCoffeeTogo"


class BiCoffee(rx.Component):
    library = "react-icons/bi"
    tag = "BiCoffee"


class BiCog(rx.Component):
    library = "react-icons/bi"
    tag = "BiCog"


class BiCoinStack(rx.Component):
    library = "react-icons/bi"
    tag = "BiCoinStack"


class BiCoin(rx.Component):
    library = "react-icons/bi"
    tag = "BiCoin"


class BiCollapseAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiCollapseAlt"


class BiCollapseHorizontal(rx.Component):
    library = "react-icons/bi"
    tag = "BiCollapseHorizontal"


class BiCollapseVertical(rx.Component):
    library = "react-icons/bi"
    tag = "BiCollapseVertical"


class BiCollapse(rx.Component):
    library = "react-icons/bi"
    tag = "BiCollapse"


class BiCollection(rx.Component):
    library = "react-icons/bi"
    tag = "BiCollection"


class BiColorFill(rx.Component):
    library = "react-icons/bi"
    tag = "BiColorFill"


class BiColor(rx.Component):
    library = "react-icons/bi"
    tag = "BiColor"


class BiColumns(rx.Component):
    library = "react-icons/bi"
    tag = "BiColumns"


class BiCommand(rx.Component):
    library = "react-icons/bi"
    tag = "BiCommand"


class BiCommentAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiCommentAdd"


class BiCommentCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiCommentCheck"


class BiCommentDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiCommentDetail"


class BiCommentDots(rx.Component):
    library = "react-icons/bi"
    tag = "BiCommentDots"


class BiCommentEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiCommentEdit"


class BiCommentError(rx.Component):
    library = "react-icons/bi"
    tag = "BiCommentError"


class BiCommentMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiCommentMinus"


class BiCommentX(rx.Component):
    library = "react-icons/bi"
    tag = "BiCommentX"


class BiComment(rx.Component):
    library = "react-icons/bi"
    tag = "BiComment"


class BiCompass(rx.Component):
    library = "react-icons/bi"
    tag = "BiCompass"


class BiConfused(rx.Component):
    library = "react-icons/bi"
    tag = "BiConfused"


class BiConversation(rx.Component):
    library = "react-icons/bi"
    tag = "BiConversation"


class BiCookie(rx.Component):
    library = "react-icons/bi"
    tag = "BiCookie"


class BiCool(rx.Component):
    library = "react-icons/bi"
    tag = "BiCool"


class BiCopyAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiCopyAlt"


class BiCopy(rx.Component):
    library = "react-icons/bi"
    tag = "BiCopy"


class BiCopyright(rx.Component):
    library = "react-icons/bi"
    tag = "BiCopyright"


class BiCreditCardAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiCreditCardAlt"


class BiCreditCardFront(rx.Component):
    library = "react-icons/bi"
    tag = "BiCreditCardFront"


class BiCreditCard(rx.Component):
    library = "react-icons/bi"
    tag = "BiCreditCard"


class BiCricketBall(rx.Component):
    library = "react-icons/bi"
    tag = "BiCricketBall"


class BiCrop(rx.Component):
    library = "react-icons/bi"
    tag = "BiCrop"


class BiCross(rx.Component):
    library = "react-icons/bi"
    tag = "BiCross"


class BiCrosshair(rx.Component):
    library = "react-icons/bi"
    tag = "BiCrosshair"


class BiCrown(rx.Component):
    library = "react-icons/bi"
    tag = "BiCrown"


class BiCubeAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiCubeAlt"


class BiCube(rx.Component):
    library = "react-icons/bi"
    tag = "BiCube"


class BiCuboid(rx.Component):
    library = "react-icons/bi"
    tag = "BiCuboid"


class BiCurrentLocation(rx.Component):
    library = "react-icons/bi"
    tag = "BiCurrentLocation"


class BiCustomize(rx.Component):
    library = "react-icons/bi"
    tag = "BiCustomize"


class BiCut(rx.Component):
    library = "react-icons/bi"
    tag = "BiCut"


class BiCycling(rx.Component):
    library = "react-icons/bi"
    tag = "BiCycling"


class BiCylinder(rx.Component):
    library = "react-icons/bi"
    tag = "BiCylinder"


class BiData(rx.Component):
    library = "react-icons/bi"
    tag = "BiData"


class BiDesktop(rx.Component):
    library = "react-icons/bi"
    tag = "BiDesktop"


class BiDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiDetail"


class BiDevices(rx.Component):
    library = "react-icons/bi"
    tag = "BiDevices"


class BiDialpadAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiDialpadAlt"


class BiDialpad(rx.Component):
    library = "react-icons/bi"
    tag = "BiDialpad"


class BiDiamond(rx.Component):
    library = "react-icons/bi"
    tag = "BiDiamond"


class BiDice1(rx.Component):
    library = "react-icons/bi"
    tag = "BiDice1"


class BiDice2(rx.Component):
    library = "react-icons/bi"
    tag = "BiDice2"


class BiDice3(rx.Component):
    library = "react-icons/bi"
    tag = "BiDice3"


class BiDice4(rx.Component):
    library = "react-icons/bi"
    tag = "BiDice4"


class BiDice5(rx.Component):
    library = "react-icons/bi"
    tag = "BiDice5"


class BiDice6(rx.Component):
    library = "react-icons/bi"
    tag = "BiDice6"


class BiDirections(rx.Component):
    library = "react-icons/bi"
    tag = "BiDirections"


class BiDisc(rx.Component):
    library = "react-icons/bi"
    tag = "BiDisc"


class BiDish(rx.Component):
    library = "react-icons/bi"
    tag = "BiDish"


class BiDislike(rx.Component):
    library = "react-icons/bi"
    tag = "BiDislike"


class BiDizzy(rx.Component):
    library = "react-icons/bi"
    tag = "BiDizzy"


class BiDna(rx.Component):
    library = "react-icons/bi"
    tag = "BiDna"


class BiDockBottom(rx.Component):
    library = "react-icons/bi"
    tag = "BiDockBottom"


class BiDockLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiDockLeft"


class BiDockRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiDockRight"


class BiDockTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiDockTop"


class BiDollarCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiDollarCircle"


class BiDollar(rx.Component):
    library = "react-icons/bi"
    tag = "BiDollar"


class BiDonateBlood(rx.Component):
    library = "react-icons/bi"
    tag = "BiDonateBlood"


class BiDonateHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiDonateHeart"


class BiDoorOpen(rx.Component):
    library = "react-icons/bi"
    tag = "BiDoorOpen"


class BiDotsHorizontalRounded(rx.Component):
    library = "react-icons/bi"
    tag = "BiDotsHorizontalRounded"


class BiDotsHorizontal(rx.Component):
    library = "react-icons/bi"
    tag = "BiDotsHorizontal"


class BiDotsVerticalRounded(rx.Component):
    library = "react-icons/bi"
    tag = "BiDotsVerticalRounded"


class BiDotsVertical(rx.Component):
    library = "react-icons/bi"
    tag = "BiDotsVertical"


class BiDoughnutChart(rx.Component):
    library = "react-icons/bi"
    tag = "BiDoughnutChart"


class BiDownArrowAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiDownArrowAlt"


class BiDownArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiDownArrowCircle"


class BiDownArrow(rx.Component):
    library = "react-icons/bi"
    tag = "BiDownArrow"


class BiDownload(rx.Component):
    library = "react-icons/bi"
    tag = "BiDownload"


class BiDownvote(rx.Component):
    library = "react-icons/bi"
    tag = "BiDownvote"


class BiDrink(rx.Component):
    library = "react-icons/bi"
    tag = "BiDrink"


class BiDroplet(rx.Component):
    library = "react-icons/bi"
    tag = "BiDroplet"


class BiDumbbell(rx.Component):
    library = "react-icons/bi"
    tag = "BiDumbbell"


class BiDuplicate(rx.Component):
    library = "react-icons/bi"
    tag = "BiDuplicate"


class BiEditAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiEditAlt"


class BiEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiEdit"


class BiEnvelopeOpen(rx.Component):
    library = "react-icons/bi"
    tag = "BiEnvelopeOpen"


class BiEnvelope(rx.Component):
    library = "react-icons/bi"
    tag = "BiEnvelope"


class BiEqualizer(rx.Component):
    library = "react-icons/bi"
    tag = "BiEqualizer"


class BiEraser(rx.Component):
    library = "react-icons/bi"
    tag = "BiEraser"


class BiErrorAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiErrorAlt"


class BiErrorCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiErrorCircle"


class BiError(rx.Component):
    library = "react-icons/bi"
    tag = "BiError"


class BiEuro(rx.Component):
    library = "react-icons/bi"
    tag = "BiEuro"


class BiExclude(rx.Component):
    library = "react-icons/bi"
    tag = "BiExclude"


class BiExitFullscreen(rx.Component):
    library = "react-icons/bi"
    tag = "BiExitFullscreen"


class BiExit(rx.Component):
    library = "react-icons/bi"
    tag = "BiExit"


class BiExpandAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiExpandAlt"


class BiExpandHorizontal(rx.Component):
    library = "react-icons/bi"
    tag = "BiExpandHorizontal"


class BiExpandVertical(rx.Component):
    library = "react-icons/bi"
    tag = "BiExpandVertical"


class BiExpand(rx.Component):
    library = "react-icons/bi"
    tag = "BiExpand"


class BiExport(rx.Component):
    library = "react-icons/bi"
    tag = "BiExport"


class BiExtension(rx.Component):
    library = "react-icons/bi"
    tag = "BiExtension"


class BiFace(rx.Component):
    library = "react-icons/bi"
    tag = "BiFace"


class BiFastForwardCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiFastForwardCircle"


class BiFastForward(rx.Component):
    library = "react-icons/bi"
    tag = "BiFastForward"


class BiFemaleSign(rx.Component):
    library = "react-icons/bi"
    tag = "BiFemaleSign"


class BiFemale(rx.Component):
    library = "react-icons/bi"
    tag = "BiFemale"


class BiFileBlank(rx.Component):
    library = "react-icons/bi"
    tag = "BiFileBlank"


class BiFileFind(rx.Component):
    library = "react-icons/bi"
    tag = "BiFileFind"


class BiFile(rx.Component):
    library = "react-icons/bi"
    tag = "BiFile"


class BiFilm(rx.Component):
    library = "react-icons/bi"
    tag = "BiFilm"


class BiFilterAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiFilterAlt"


class BiFilter(rx.Component):
    library = "react-icons/bi"
    tag = "BiFilter"


class BiFingerprint(rx.Component):
    library = "react-icons/bi"
    tag = "BiFingerprint"


class BiFirstAid(rx.Component):
    library = "react-icons/bi"
    tag = "BiFirstAid"


class BiFirstPage(rx.Component):
    library = "react-icons/bi"
    tag = "BiFirstPage"


class BiFlag(rx.Component):
    library = "react-icons/bi"
    tag = "BiFlag"


class BiFolderMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiFolderMinus"


class BiFolderOpen(rx.Component):
    library = "react-icons/bi"
    tag = "BiFolderOpen"


class BiFolderPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiFolderPlus"


class BiFolder(rx.Component):
    library = "react-icons/bi"
    tag = "BiFolder"


class BiFontColor(rx.Component):
    library = "react-icons/bi"
    tag = "BiFontColor"


class BiFontFamily(rx.Component):
    library = "react-icons/bi"
    tag = "BiFontFamily"


class BiFontSize(rx.Component):
    library = "react-icons/bi"
    tag = "BiFontSize"


class BiFont(rx.Component):
    library = "react-icons/bi"
    tag = "BiFont"


class BiFoodMenu(rx.Component):
    library = "react-icons/bi"
    tag = "BiFoodMenu"


class BiFoodTag(rx.Component):
    library = "react-icons/bi"
    tag = "BiFoodTag"


class BiFootball(rx.Component):
    library = "react-icons/bi"
    tag = "BiFootball"


class BiFork(rx.Component):
    library = "react-icons/bi"
    tag = "BiFork"


class BiFridge(rx.Component):
    library = "react-icons/bi"
    tag = "BiFridge"


class BiFullscreen(rx.Component):
    library = "react-icons/bi"
    tag = "BiFullscreen"


class BiGame(rx.Component):
    library = "react-icons/bi"
    tag = "BiGame"


class BiGasPump(rx.Component):
    library = "react-icons/bi"
    tag = "BiGasPump"


class BiGhost(rx.Component):
    library = "react-icons/bi"
    tag = "BiGhost"


class BiGift(rx.Component):
    library = "react-icons/bi"
    tag = "BiGift"


class BiGitBranch(rx.Component):
    library = "react-icons/bi"
    tag = "BiGitBranch"


class BiGitCommit(rx.Component):
    library = "react-icons/bi"
    tag = "BiGitCommit"


class BiGitCompare(rx.Component):
    library = "react-icons/bi"
    tag = "BiGitCompare"


class BiGitMerge(rx.Component):
    library = "react-icons/bi"
    tag = "BiGitMerge"


class BiGitPullRequest(rx.Component):
    library = "react-icons/bi"
    tag = "BiGitPullRequest"


class BiGitRepoForked(rx.Component):
    library = "react-icons/bi"
    tag = "BiGitRepoForked"


class BiGlassesAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiGlassesAlt"


class BiGlasses(rx.Component):
    library = "react-icons/bi"
    tag = "BiGlasses"


class BiGlobeAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiGlobeAlt"


class BiGlobe(rx.Component):
    library = "react-icons/bi"
    tag = "BiGlobe"


class BiGridAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiGridAlt"


class BiGridHorizontal(rx.Component):
    library = "react-icons/bi"
    tag = "BiGridHorizontal"


class BiGridSmall(rx.Component):
    library = "react-icons/bi"
    tag = "BiGridSmall"


class BiGridVertical(rx.Component):
    library = "react-icons/bi"
    tag = "BiGridVertical"


class BiGrid(rx.Component):
    library = "react-icons/bi"
    tag = "BiGrid"


class BiGroup(rx.Component):
    library = "react-icons/bi"
    tag = "BiGroup"


class BiHandicap(rx.Component):
    library = "react-icons/bi"
    tag = "BiHandicap"


class BiHappyAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiHappyAlt"


class BiHappyBeaming(rx.Component):
    library = "react-icons/bi"
    tag = "BiHappyBeaming"


class BiHappyHeartEyes(rx.Component):
    library = "react-icons/bi"
    tag = "BiHappyHeartEyes"


class BiHappy(rx.Component):
    library = "react-icons/bi"
    tag = "BiHappy"


class BiHardHat(rx.Component):
    library = "react-icons/bi"
    tag = "BiHardHat"


class BiHash(rx.Component):
    library = "react-icons/bi"
    tag = "BiHash"


class BiHdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiHdd"


class BiHeading(rx.Component):
    library = "react-icons/bi"
    tag = "BiHeading"


class BiHeadphone(rx.Component):
    library = "react-icons/bi"
    tag = "BiHeadphone"


class BiHealth(rx.Component):
    library = "react-icons/bi"
    tag = "BiHealth"


class BiHeartCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiHeartCircle"


class BiHeartSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiHeartSquare"


class BiHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiHeart"


class BiHelpCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiHelpCircle"


class BiHide(rx.Component):
    library = "react-icons/bi"
    tag = "BiHide"


class BiHighlight(rx.Component):
    library = "react-icons/bi"
    tag = "BiHighlight"


class BiHistory(rx.Component):
    library = "react-icons/bi"
    tag = "BiHistory"


class BiHive(rx.Component):
    library = "react-icons/bi"
    tag = "BiHive"


class BiHomeAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiHomeAlt2"


class BiHomeAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiHomeAlt"


class BiHomeCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiHomeCircle"


class BiHomeHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiHomeHeart"


class BiHomeSmile(rx.Component):
    library = "react-icons/bi"
    tag = "BiHomeSmile"


class BiHome(rx.Component):
    library = "react-icons/bi"
    tag = "BiHome"


class BiHorizontalCenter(rx.Component):
    library = "react-icons/bi"
    tag = "BiHorizontalCenter"


class BiHorizontalLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiHorizontalLeft"


class BiHorizontalRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiHorizontalRight"


class BiHotel(rx.Component):
    library = "react-icons/bi"
    tag = "BiHotel"


class BiHourglass(rx.Component):
    library = "react-icons/bi"
    tag = "BiHourglass"


class BiIdCard(rx.Component):
    library = "react-icons/bi"
    tag = "BiIdCard"


class BiImageAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiImageAdd"


class BiImageAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiImageAlt"


class BiImage(rx.Component):
    library = "react-icons/bi"
    tag = "BiImage"


class BiImages(rx.Component):
    library = "react-icons/bi"
    tag = "BiImages"


class BiImport(rx.Component):
    library = "react-icons/bi"
    tag = "BiImport"


class BiInfinite(rx.Component):
    library = "react-icons/bi"
    tag = "BiInfinite"


class BiInfoCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiInfoCircle"


class BiInfoSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiInfoSquare"


class BiInjection(rx.Component):
    library = "react-icons/bi"
    tag = "BiInjection"


class BiIntersect(rx.Component):
    library = "react-icons/bi"
    tag = "BiIntersect"


class BiItalic(rx.Component):
    library = "react-icons/bi"
    tag = "BiItalic"


class BiJoystickAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiJoystickAlt"


class BiJoystickButton(rx.Component):
    library = "react-icons/bi"
    tag = "BiJoystickButton"


class BiJoystick(rx.Component):
    library = "react-icons/bi"
    tag = "BiJoystick"


class BiKey(rx.Component):
    library = "react-icons/bi"
    tag = "BiKey"


class BiKnife(rx.Component):
    library = "react-icons/bi"
    tag = "BiKnife"


class BiLabel(rx.Component):
    library = "react-icons/bi"
    tag = "BiLabel"


class BiLandscape(rx.Component):
    library = "react-icons/bi"
    tag = "BiLandscape"


class BiLaptop(rx.Component):
    library = "react-icons/bi"
    tag = "BiLaptop"


class BiLastPage(rx.Component):
    library = "react-icons/bi"
    tag = "BiLastPage"


class BiLaugh(rx.Component):
    library = "react-icons/bi"
    tag = "BiLaugh"


class BiLayerMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiLayerMinus"


class BiLayerPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiLayerPlus"


class BiLayer(rx.Component):
    library = "react-icons/bi"
    tag = "BiLayer"


class BiLayout(rx.Component):
    library = "react-icons/bi"
    tag = "BiLayout"


class BiLeaf(rx.Component):
    library = "react-icons/bi"
    tag = "BiLeaf"


class BiLeftArrowAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiLeftArrowAlt"


class BiLeftArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiLeftArrowCircle"


class BiLeftArrow(rx.Component):
    library = "react-icons/bi"
    tag = "BiLeftArrow"


class BiLeftDownArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiLeftDownArrowCircle"


class BiLeftIndent(rx.Component):
    library = "react-icons/bi"
    tag = "BiLeftIndent"


class BiLeftTopArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiLeftTopArrowCircle"


class BiLemon(rx.Component):
    library = "react-icons/bi"
    tag = "BiLemon"


class BiLibrary(rx.Component):
    library = "react-icons/bi"
    tag = "BiLibrary"


class BiLike(rx.Component):
    library = "react-icons/bi"
    tag = "BiLike"


class BiLineChartDown(rx.Component):
    library = "react-icons/bi"
    tag = "BiLineChartDown"


class BiLineChart(rx.Component):
    library = "react-icons/bi"
    tag = "BiLineChart"


class BiLinkAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiLinkAlt"


class BiLinkExternal(rx.Component):
    library = "react-icons/bi"
    tag = "BiLinkExternal"


class BiLink(rx.Component):
    library = "react-icons/bi"
    tag = "BiLink"


class BiLira(rx.Component):
    library = "react-icons/bi"
    tag = "BiLira"


class BiListCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiListCheck"


class BiListMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiListMinus"


class BiListOl(rx.Component):
    library = "react-icons/bi"
    tag = "BiListOl"


class BiListPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiListPlus"


class BiListUl(rx.Component):
    library = "react-icons/bi"
    tag = "BiListUl"


class BiLoaderAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiLoaderAlt"


class BiLoaderCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiLoaderCircle"


class BiLoader(rx.Component):
    library = "react-icons/bi"
    tag = "BiLoader"


class BiLocationPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiLocationPlus"


class BiLockAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiLockAlt"


class BiLockOpenAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiLockOpenAlt"


class BiLockOpen(rx.Component):
    library = "react-icons/bi"
    tag = "BiLockOpen"


class BiLock(rx.Component):
    library = "react-icons/bi"
    tag = "BiLock"


class BiLogInCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogInCircle"


class BiLogIn(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogIn"


class BiLogOutCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogOutCircle"


class BiLogOut(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogOut"


class BiLowVision(rx.Component):
    library = "react-icons/bi"
    tag = "BiLowVision"


class BiMagnet(rx.Component):
    library = "react-icons/bi"
    tag = "BiMagnet"


class BiMailSend(rx.Component):
    library = "react-icons/bi"
    tag = "BiMailSend"


class BiMaleFemale(rx.Component):
    library = "react-icons/bi"
    tag = "BiMaleFemale"


class BiMaleSign(rx.Component):
    library = "react-icons/bi"
    tag = "BiMaleSign"


class BiMale(rx.Component):
    library = "react-icons/bi"
    tag = "BiMale"


class BiMapAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiMapAlt"


class BiMapPin(rx.Component):
    library = "react-icons/bi"
    tag = "BiMapPin"


class BiMap(rx.Component):
    library = "react-icons/bi"
    tag = "BiMap"


class BiMask(rx.Component):
    library = "react-icons/bi"
    tag = "BiMask"


class BiMath(rx.Component):
    library = "react-icons/bi"
    tag = "BiMath"


class BiMedal(rx.Component):
    library = "react-icons/bi"
    tag = "BiMedal"


class BiMehAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiMehAlt"


class BiMehBlank(rx.Component):
    library = "react-icons/bi"
    tag = "BiMehBlank"


class BiMeh(rx.Component):
    library = "react-icons/bi"
    tag = "BiMeh"


class BiMemoryCard(rx.Component):
    library = "react-icons/bi"
    tag = "BiMemoryCard"


class BiMenuAltLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiMenuAltLeft"


class BiMenuAltRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiMenuAltRight"


class BiMenu(rx.Component):
    library = "react-icons/bi"
    tag = "BiMenu"


class BiMerge(rx.Component):
    library = "react-icons/bi"
    tag = "BiMerge"


class BiMessageAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageAdd"


class BiMessageAltAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageAltAdd"


class BiMessageAltCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageAltCheck"


class BiMessageAltDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageAltDetail"


class BiMessageAltDots(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageAltDots"


class BiMessageAltEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageAltEdit"


class BiMessageAltError(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageAltError"


class BiMessageAltMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageAltMinus"


class BiMessageAltX(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageAltX"


class BiMessageAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageAlt"


class BiMessageCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageCheck"


class BiMessageDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageDetail"


class BiMessageDots(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageDots"


class BiMessageEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageEdit"


class BiMessageError(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageError"


class BiMessageMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageMinus"


class BiMessageRoundedAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageRoundedAdd"


class BiMessageRoundedCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageRoundedCheck"


class BiMessageRoundedDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageRoundedDetail"


class BiMessageRoundedDots(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageRoundedDots"


class BiMessageRoundedEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageRoundedEdit"


class BiMessageRoundedError(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageRoundedError"


class BiMessageRoundedMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageRoundedMinus"


class BiMessageRoundedX(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageRoundedX"


class BiMessageRounded(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageRounded"


class BiMessageSquareAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageSquareAdd"


class BiMessageSquareCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageSquareCheck"


class BiMessageSquareDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageSquareDetail"


class BiMessageSquareDots(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageSquareDots"


class BiMessageSquareEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageSquareEdit"


class BiMessageSquareError(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageSquareError"


class BiMessageSquareMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageSquareMinus"


class BiMessageSquareX(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageSquareX"


class BiMessageSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageSquare"


class BiMessageX(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessageX"


class BiMessage(rx.Component):
    library = "react-icons/bi"
    tag = "BiMessage"


class BiMeteor(rx.Component):
    library = "react-icons/bi"
    tag = "BiMeteor"


class BiMicrochip(rx.Component):
    library = "react-icons/bi"
    tag = "BiMicrochip"


class BiMicrophoneOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiMicrophoneOff"


class BiMicrophone(rx.Component):
    library = "react-icons/bi"
    tag = "BiMicrophone"


class BiMinusBack(rx.Component):
    library = "react-icons/bi"
    tag = "BiMinusBack"


class BiMinusCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiMinusCircle"


class BiMinusFront(rx.Component):
    library = "react-icons/bi"
    tag = "BiMinusFront"


class BiMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiMinus"


class BiMobileAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiMobileAlt"


class BiMobileLandscape(rx.Component):
    library = "react-icons/bi"
    tag = "BiMobileLandscape"


class BiMobileVibration(rx.Component):
    library = "react-icons/bi"
    tag = "BiMobileVibration"


class BiMobile(rx.Component):
    library = "react-icons/bi"
    tag = "BiMobile"


class BiMoneyWithdraw(rx.Component):
    library = "react-icons/bi"
    tag = "BiMoneyWithdraw"


class BiMoney(rx.Component):
    library = "react-icons/bi"
    tag = "BiMoney"


class BiMoon(rx.Component):
    library = "react-icons/bi"
    tag = "BiMoon"


class BiMouseAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiMouseAlt"


class BiMouse(rx.Component):
    library = "react-icons/bi"
    tag = "BiMouse"


class BiMoveHorizontal(rx.Component):
    library = "react-icons/bi"
    tag = "BiMoveHorizontal"


class BiMoveVertical(rx.Component):
    library = "react-icons/bi"
    tag = "BiMoveVertical"


class BiMove(rx.Component):
    library = "react-icons/bi"
    tag = "BiMove"


class BiMoviePlay(rx.Component):
    library = "react-icons/bi"
    tag = "BiMoviePlay"


class BiMovie(rx.Component):
    library = "react-icons/bi"
    tag = "BiMovie"


class BiMusic(rx.Component):
    library = "react-icons/bi"
    tag = "BiMusic"


class BiNavigation(rx.Component):
    library = "react-icons/bi"
    tag = "BiNavigation"


class BiNetworkChart(rx.Component):
    library = "react-icons/bi"
    tag = "BiNetworkChart"


class BiNews(rx.Component):
    library = "react-icons/bi"
    tag = "BiNews"


class BiNoEntry(rx.Component):
    library = "react-icons/bi"
    tag = "BiNoEntry"


class BiNoSignal(rx.Component):
    library = "react-icons/bi"
    tag = "BiNoSignal"


class BiNote(rx.Component):
    library = "react-icons/bi"
    tag = "BiNote"


class BiNotepad(rx.Component):
    library = "react-icons/bi"
    tag = "BiNotepad"


class BiNotificationOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiNotificationOff"


class BiNotification(rx.Component):
    library = "react-icons/bi"
    tag = "BiNotification"


class BiObjectsHorizontalCenter(rx.Component):
    library = "react-icons/bi"
    tag = "BiObjectsHorizontalCenter"


class BiObjectsHorizontalLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiObjectsHorizontalLeft"


class BiObjectsHorizontalRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiObjectsHorizontalRight"


class BiObjectsVerticalBottom(rx.Component):
    library = "react-icons/bi"
    tag = "BiObjectsVerticalBottom"


class BiObjectsVerticalCenter(rx.Component):
    library = "react-icons/bi"
    tag = "BiObjectsVerticalCenter"


class BiObjectsVerticalTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiObjectsVerticalTop"


class BiOutline(rx.Component):
    library = "react-icons/bi"
    tag = "BiOutline"


class BiPackage(rx.Component):
    library = "react-icons/bi"
    tag = "BiPackage"


class BiPaintRoll(rx.Component):
    library = "react-icons/bi"
    tag = "BiPaintRoll"


class BiPaint(rx.Component):
    library = "react-icons/bi"
    tag = "BiPaint"


class BiPalette(rx.Component):
    library = "react-icons/bi"
    tag = "BiPalette"


class BiPaperPlane(rx.Component):
    library = "react-icons/bi"
    tag = "BiPaperPlane"


class BiPaperclip(rx.Component):
    library = "react-icons/bi"
    tag = "BiPaperclip"


class BiParagraph(rx.Component):
    library = "react-icons/bi"
    tag = "BiParagraph"


class BiParty(rx.Component):
    library = "react-icons/bi"
    tag = "BiParty"


class BiPaste(rx.Component):
    library = "react-icons/bi"
    tag = "BiPaste"


class BiPauseCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiPauseCircle"


class BiPause(rx.Component):
    library = "react-icons/bi"
    tag = "BiPause"


class BiPen(rx.Component):
    library = "react-icons/bi"
    tag = "BiPen"


class BiPencil(rx.Component):
    library = "react-icons/bi"
    tag = "BiPencil"


class BiPhoneCall(rx.Component):
    library = "react-icons/bi"
    tag = "BiPhoneCall"


class BiPhoneIncoming(rx.Component):
    library = "react-icons/bi"
    tag = "BiPhoneIncoming"


class BiPhoneOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiPhoneOff"


class BiPhoneOutgoing(rx.Component):
    library = "react-icons/bi"
    tag = "BiPhoneOutgoing"


class BiPhone(rx.Component):
    library = "react-icons/bi"
    tag = "BiPhone"


class BiPhotoAlbum(rx.Component):
    library = "react-icons/bi"
    tag = "BiPhotoAlbum"


class BiPieChartAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiPieChartAlt2"


class BiPieChartAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiPieChartAlt"


class BiPieChart(rx.Component):
    library = "react-icons/bi"
    tag = "BiPieChart"


class BiPin(rx.Component):
    library = "react-icons/bi"
    tag = "BiPin"


class BiPlanet(rx.Component):
    library = "react-icons/bi"
    tag = "BiPlanet"


class BiPlayCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiPlayCircle"


class BiPlay(rx.Component):
    library = "react-icons/bi"
    tag = "BiPlay"


class BiPlug(rx.Component):
    library = "react-icons/bi"
    tag = "BiPlug"


class BiPlusCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiPlusCircle"


class BiPlusMedical(rx.Component):
    library = "react-icons/bi"
    tag = "BiPlusMedical"


class BiPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiPlus"


class BiPodcast(rx.Component):
    library = "react-icons/bi"
    tag = "BiPodcast"


class BiPointer(rx.Component):
    library = "react-icons/bi"
    tag = "BiPointer"


class BiPoll(rx.Component):
    library = "react-icons/bi"
    tag = "BiPoll"


class BiPolygon(rx.Component):
    library = "react-icons/bi"
    tag = "BiPolygon"


class BiPopsicle(rx.Component):
    library = "react-icons/bi"
    tag = "BiPopsicle"


class BiPound(rx.Component):
    library = "react-icons/bi"
    tag = "BiPound"


class BiPowerOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiPowerOff"


class BiPrinter(rx.Component):
    library = "react-icons/bi"
    tag = "BiPrinter"


class BiPulse(rx.Component):
    library = "react-icons/bi"
    tag = "BiPulse"


class BiPurchaseTagAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiPurchaseTagAlt"


class BiPurchaseTag(rx.Component):
    library = "react-icons/bi"
    tag = "BiPurchaseTag"


class BiPyramid(rx.Component):
    library = "react-icons/bi"
    tag = "BiPyramid"


class BiQrScan(rx.Component):
    library = "react-icons/bi"
    tag = "BiQrScan"


class BiQr(rx.Component):
    library = "react-icons/bi"
    tag = "BiQr"


class BiQuestionMark(rx.Component):
    library = "react-icons/bi"
    tag = "BiQuestionMark"


class BiRadar(rx.Component):
    library = "react-icons/bi"
    tag = "BiRadar"


class BiRadioCircleMarked(rx.Component):
    library = "react-icons/bi"
    tag = "BiRadioCircleMarked"


class BiRadioCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiRadioCircle"


class BiRadio(rx.Component):
    library = "react-icons/bi"
    tag = "BiRadio"


class BiReceipt(rx.Component):
    library = "react-icons/bi"
    tag = "BiReceipt"


class BiRectangle(rx.Component):
    library = "react-icons/bi"
    tag = "BiRectangle"


class BiRecycle(rx.Component):
    library = "react-icons/bi"
    tag = "BiRecycle"


class BiRedo(rx.Component):
    library = "react-icons/bi"
    tag = "BiRedo"


class BiReflectHorizontal(rx.Component):
    library = "react-icons/bi"
    tag = "BiReflectHorizontal"


class BiReflectVertical(rx.Component):
    library = "react-icons/bi"
    tag = "BiReflectVertical"


class BiRefresh(rx.Component):
    library = "react-icons/bi"
    tag = "BiRefresh"


class BiRegistered(rx.Component):
    library = "react-icons/bi"
    tag = "BiRegistered"


class BiRename(rx.Component):
    library = "react-icons/bi"
    tag = "BiRename"


class BiRepeat(rx.Component):
    library = "react-icons/bi"
    tag = "BiRepeat"


class BiReplyAll(rx.Component):
    library = "react-icons/bi"
    tag = "BiReplyAll"


class BiReply(rx.Component):
    library = "react-icons/bi"
    tag = "BiReply"


class BiRepost(rx.Component):
    library = "react-icons/bi"
    tag = "BiRepost"


class BiReset(rx.Component):
    library = "react-icons/bi"
    tag = "BiReset"


class BiRestaurant(rx.Component):
    library = "react-icons/bi"
    tag = "BiRestaurant"


class BiRevision(rx.Component):
    library = "react-icons/bi"
    tag = "BiRevision"


class BiRewindCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiRewindCircle"


class BiRewind(rx.Component):
    library = "react-icons/bi"
    tag = "BiRewind"


class BiRfid(rx.Component):
    library = "react-icons/bi"
    tag = "BiRfid"


class BiRightArrowAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiRightArrowAlt"


class BiRightArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiRightArrowCircle"


class BiRightArrow(rx.Component):
    library = "react-icons/bi"
    tag = "BiRightArrow"


class BiRightDownArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiRightDownArrowCircle"


class BiRightIndent(rx.Component):
    library = "react-icons/bi"
    tag = "BiRightIndent"


class BiRightTopArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiRightTopArrowCircle"


class BiRocket(rx.Component):
    library = "react-icons/bi"
    tag = "BiRocket"


class BiRotateLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiRotateLeft"


class BiRotateRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiRotateRight"


class BiRss(rx.Component):
    library = "react-icons/bi"
    tag = "BiRss"


class BiRuble(rx.Component):
    library = "react-icons/bi"
    tag = "BiRuble"


class BiRuler(rx.Component):
    library = "react-icons/bi"
    tag = "BiRuler"


class BiRun(rx.Component):
    library = "react-icons/bi"
    tag = "BiRun"


class BiRupee(rx.Component):
    library = "react-icons/bi"
    tag = "BiRupee"


class BiSad(rx.Component):
    library = "react-icons/bi"
    tag = "BiSad"


class BiSave(rx.Component):
    library = "react-icons/bi"
    tag = "BiSave"


class BiScan(rx.Component):
    library = "react-icons/bi"
    tag = "BiScan"


class BiScatterChart(rx.Component):
    library = "react-icons/bi"
    tag = "BiScatterChart"


class BiScreenshot(rx.Component):
    library = "react-icons/bi"
    tag = "BiScreenshot"


class BiSearchAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiSearchAlt2"


class BiSearchAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSearchAlt"


class BiSearch(rx.Component):
    library = "react-icons/bi"
    tag = "BiSearch"


class BiSelectMultiple(rx.Component):
    library = "react-icons/bi"
    tag = "BiSelectMultiple"


class BiSelection(rx.Component):
    library = "react-icons/bi"
    tag = "BiSelection"


class BiSend(rx.Component):
    library = "react-icons/bi"
    tag = "BiSend"


class BiServer(rx.Component):
    library = "react-icons/bi"
    tag = "BiServer"


class BiShapeCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiShapeCircle"


class BiShapePolygon(rx.Component):
    library = "react-icons/bi"
    tag = "BiShapePolygon"


class BiShapeSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiShapeSquare"


class BiShapeTriangle(rx.Component):
    library = "react-icons/bi"
    tag = "BiShapeTriangle"


class BiShareAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiShareAlt"


class BiShare(rx.Component):
    library = "react-icons/bi"
    tag = "BiShare"


class BiShekel(rx.Component):
    library = "react-icons/bi"
    tag = "BiShekel"


class BiShieldAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiShieldAlt2"


class BiShieldAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiShieldAlt"


class BiShieldMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiShieldMinus"


class BiShieldPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiShieldPlus"


class BiShieldQuarter(rx.Component):
    library = "react-icons/bi"
    tag = "BiShieldQuarter"


class BiShieldX(rx.Component):
    library = "react-icons/bi"
    tag = "BiShieldX"


class BiShield(rx.Component):
    library = "react-icons/bi"
    tag = "BiShield"


class BiShocked(rx.Component):
    library = "react-icons/bi"
    tag = "BiShocked"


class BiShoppingBag(rx.Component):
    library = "react-icons/bi"
    tag = "BiShoppingBag"


class BiShowAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiShowAlt"


class BiShow(rx.Component):
    library = "react-icons/bi"
    tag = "BiShow"


class BiShower(rx.Component):
    library = "react-icons/bi"
    tag = "BiShower"


class BiShuffle(rx.Component):
    library = "react-icons/bi"
    tag = "BiShuffle"


class BiSidebar(rx.Component):
    library = "react-icons/bi"
    tag = "BiSidebar"


class BiSignal1(rx.Component):
    library = "react-icons/bi"
    tag = "BiSignal1"


class BiSignal2(rx.Component):
    library = "react-icons/bi"
    tag = "BiSignal2"


class BiSignal3(rx.Component):
    library = "react-icons/bi"
    tag = "BiSignal3"


class BiSignal4(rx.Component):
    library = "react-icons/bi"
    tag = "BiSignal4"


class BiSignal5(rx.Component):
    library = "react-icons/bi"
    tag = "BiSignal5"


class BiSitemap(rx.Component):
    library = "react-icons/bi"
    tag = "BiSitemap"


class BiSkipNextCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSkipNextCircle"


class BiSkipNext(rx.Component):
    library = "react-icons/bi"
    tag = "BiSkipNext"


class BiSkipPreviousCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSkipPreviousCircle"


class BiSkipPrevious(rx.Component):
    library = "react-icons/bi"
    tag = "BiSkipPrevious"


class BiSleepy(rx.Component):
    library = "react-icons/bi"
    tag = "BiSleepy"


class BiSliderAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSliderAlt"


class BiSlider(rx.Component):
    library = "react-icons/bi"
    tag = "BiSlider"


class BiSlideshow(rx.Component):
    library = "react-icons/bi"
    tag = "BiSlideshow"


class BiSmile(rx.Component):
    library = "react-icons/bi"
    tag = "BiSmile"


class BiSortAZ(rx.Component):
    library = "react-icons/bi"
    tag = "BiSortAZ"


class BiSortAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiSortAlt2"


class BiSortDown(rx.Component):
    library = "react-icons/bi"
    tag = "BiSortDown"


class BiSortUp(rx.Component):
    library = "react-icons/bi"
    tag = "BiSortUp"


class BiSortZA(rx.Component):
    library = "react-icons/bi"
    tag = "BiSortZA"


class BiSort(rx.Component):
    library = "react-icons/bi"
    tag = "BiSort"


class BiSpa(rx.Component):
    library = "react-icons/bi"
    tag = "BiSpa"


class BiSpaceBar(rx.Component):
    library = "react-icons/bi"
    tag = "BiSpaceBar"


class BiSpeaker(rx.Component):
    library = "react-icons/bi"
    tag = "BiSpeaker"


class BiSprayCan(rx.Component):
    library = "react-icons/bi"
    tag = "BiSprayCan"


class BiSpreadsheet(rx.Component):
    library = "react-icons/bi"
    tag = "BiSpreadsheet"


class BiSquareRounded(rx.Component):
    library = "react-icons/bi"
    tag = "BiSquareRounded"


class BiSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSquare"


class BiStar(rx.Component):
    library = "react-icons/bi"
    tag = "BiStar"


class BiStation(rx.Component):
    library = "react-icons/bi"
    tag = "BiStation"


class BiStats(rx.Component):
    library = "react-icons/bi"
    tag = "BiStats"


class BiSticker(rx.Component):
    library = "react-icons/bi"
    tag = "BiSticker"


class BiStopCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiStopCircle"


class BiStop(rx.Component):
    library = "react-icons/bi"
    tag = "BiStop"


class BiStopwatch(rx.Component):
    library = "react-icons/bi"
    tag = "BiStopwatch"


class BiStoreAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiStoreAlt"


class BiStore(rx.Component):
    library = "react-icons/bi"
    tag = "BiStore"


class BiStreetView(rx.Component):
    library = "react-icons/bi"
    tag = "BiStreetView"


class BiStrikethrough(rx.Component):
    library = "react-icons/bi"
    tag = "BiStrikethrough"


class BiSubdirectoryLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSubdirectoryLeft"


class BiSubdirectoryRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSubdirectoryRight"


class BiSun(rx.Component):
    library = "react-icons/bi"
    tag = "BiSun"


class BiSupport(rx.Component):
    library = "react-icons/bi"
    tag = "BiSupport"


class BiSushi(rx.Component):
    library = "react-icons/bi"
    tag = "BiSushi"


class BiSwim(rx.Component):
    library = "react-icons/bi"
    tag = "BiSwim"


class BiSync(rx.Component):
    library = "react-icons/bi"
    tag = "BiSync"


class BiTab(rx.Component):
    library = "react-icons/bi"
    tag = "BiTab"


class BiTable(rx.Component):
    library = "react-icons/bi"
    tag = "BiTable"


class BiTachometer(rx.Component):
    library = "react-icons/bi"
    tag = "BiTachometer"


class BiTagAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiTagAlt"


class BiTag(rx.Component):
    library = "react-icons/bi"
    tag = "BiTag"


class BiTargetLock(rx.Component):
    library = "react-icons/bi"
    tag = "BiTargetLock"


class BiTaskX(rx.Component):
    library = "react-icons/bi"
    tag = "BiTaskX"


class BiTask(rx.Component):
    library = "react-icons/bi"
    tag = "BiTask"


class BiTaxi(rx.Component):
    library = "react-icons/bi"
    tag = "BiTaxi"


class BiTennisBall(rx.Component):
    library = "react-icons/bi"
    tag = "BiTennisBall"


class BiTerminal(rx.Component):
    library = "react-icons/bi"
    tag = "BiTerminal"


class BiTestTube(rx.Component):
    library = "react-icons/bi"
    tag = "BiTestTube"


class BiText(rx.Component):
    library = "react-icons/bi"
    tag = "BiText"


class BiTimeFive(rx.Component):
    library = "react-icons/bi"
    tag = "BiTimeFive"


class BiTime(rx.Component):
    library = "react-icons/bi"
    tag = "BiTime"


class BiTimer(rx.Component):
    library = "react-icons/bi"
    tag = "BiTimer"


class BiTired(rx.Component):
    library = "react-icons/bi"
    tag = "BiTired"


class BiToggleLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiToggleLeft"


class BiToggleRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiToggleRight"


class BiTone(rx.Component):
    library = "react-icons/bi"
    tag = "BiTone"


class BiTrafficCone(rx.Component):
    library = "react-icons/bi"
    tag = "BiTrafficCone"


class BiTrain(rx.Component):
    library = "react-icons/bi"
    tag = "BiTrain"


class BiTransferAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiTransferAlt"


class BiTransfer(rx.Component):
    library = "react-icons/bi"
    tag = "BiTransfer"


class BiTrashAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiTrashAlt"


class BiTrash(rx.Component):
    library = "react-icons/bi"
    tag = "BiTrash"


class BiTrendingDown(rx.Component):
    library = "react-icons/bi"
    tag = "BiTrendingDown"


class BiTrendingUp(rx.Component):
    library = "react-icons/bi"
    tag = "BiTrendingUp"


class BiTrim(rx.Component):
    library = "react-icons/bi"
    tag = "BiTrim"


class BiTrip(rx.Component):
    library = "react-icons/bi"
    tag = "BiTrip"


class BiTrophy(rx.Component):
    library = "react-icons/bi"
    tag = "BiTrophy"


class BiTv(rx.Component):
    library = "react-icons/bi"
    tag = "BiTv"


class BiUnderline(rx.Component):
    library = "react-icons/bi"
    tag = "BiUnderline"


class BiUndo(rx.Component):
    library = "react-icons/bi"
    tag = "BiUndo"


class BiUnite(rx.Component):
    library = "react-icons/bi"
    tag = "BiUnite"


class BiUniversalAccess(rx.Component):
    library = "react-icons/bi"
    tag = "BiUniversalAccess"


class BiUnlink(rx.Component):
    library = "react-icons/bi"
    tag = "BiUnlink"


class BiUpArrowAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiUpArrowAlt"


class BiUpArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiUpArrowCircle"


class BiUpArrow(rx.Component):
    library = "react-icons/bi"
    tag = "BiUpArrow"


class BiUpload(rx.Component):
    library = "react-icons/bi"
    tag = "BiUpload"


class BiUpsideDown(rx.Component):
    library = "react-icons/bi"
    tag = "BiUpsideDown"


class BiUpvote(rx.Component):
    library = "react-icons/bi"
    tag = "BiUpvote"


class BiUsb(rx.Component):
    library = "react-icons/bi"
    tag = "BiUsb"


class BiUserCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiUserCheck"


class BiUserCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiUserCircle"


class BiUserMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiUserMinus"


class BiUserPin(rx.Component):
    library = "react-icons/bi"
    tag = "BiUserPin"


class BiUserPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiUserPlus"


class BiUserVoice(rx.Component):
    library = "react-icons/bi"
    tag = "BiUserVoice"


class BiUserX(rx.Component):
    library = "react-icons/bi"
    tag = "BiUserX"


class BiUser(rx.Component):
    library = "react-icons/bi"
    tag = "BiUser"


class BiVector(rx.Component):
    library = "react-icons/bi"
    tag = "BiVector"


class BiVerticalBottom(rx.Component):
    library = "react-icons/bi"
    tag = "BiVerticalBottom"


class BiVerticalCenter(rx.Component):
    library = "react-icons/bi"
    tag = "BiVerticalCenter"


class BiVerticalTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiVerticalTop"


class BiVial(rx.Component):
    library = "react-icons/bi"
    tag = "BiVial"


class BiVideoOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiVideoOff"


class BiVideoPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiVideoPlus"


class BiVideoRecording(rx.Component):
    library = "react-icons/bi"
    tag = "BiVideoRecording"


class BiVideo(rx.Component):
    library = "react-icons/bi"
    tag = "BiVideo"


class BiVoicemail(rx.Component):
    library = "react-icons/bi"
    tag = "BiVoicemail"


class BiVolumeFull(rx.Component):
    library = "react-icons/bi"
    tag = "BiVolumeFull"


class BiVolumeLow(rx.Component):
    library = "react-icons/bi"
    tag = "BiVolumeLow"


class BiVolumeMute(rx.Component):
    library = "react-icons/bi"
    tag = "BiVolumeMute"


class BiVolume(rx.Component):
    library = "react-icons/bi"
    tag = "BiVolume"


class BiWalk(rx.Component):
    library = "react-icons/bi"
    tag = "BiWalk"


class BiWalletAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiWalletAlt"


class BiWallet(rx.Component):
    library = "react-icons/bi"
    tag = "BiWallet"


class BiWater(rx.Component):
    library = "react-icons/bi"
    tag = "BiWater"


class BiWebcam(rx.Component):
    library = "react-icons/bi"
    tag = "BiWebcam"


class BiWifi0(rx.Component):
    library = "react-icons/bi"
    tag = "BiWifi0"


class BiWifi1(rx.Component):
    library = "react-icons/bi"
    tag = "BiWifi1"


class BiWifi2(rx.Component):
    library = "react-icons/bi"
    tag = "BiWifi2"


class BiWifiOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiWifiOff"


class BiWifi(rx.Component):
    library = "react-icons/bi"
    tag = "BiWifi"


class BiWind(rx.Component):
    library = "react-icons/bi"
    tag = "BiWind"


class BiWindowAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiWindowAlt"


class BiWindowClose(rx.Component):
    library = "react-icons/bi"
    tag = "BiWindowClose"


class BiWindowOpen(rx.Component):
    library = "react-icons/bi"
    tag = "BiWindowOpen"


class BiWindow(rx.Component):
    library = "react-icons/bi"
    tag = "BiWindow"


class BiWindows(rx.Component):
    library = "react-icons/bi"
    tag = "BiWindows"


class BiWine(rx.Component):
    library = "react-icons/bi"
    tag = "BiWine"


class BiWinkSmile(rx.Component):
    library = "react-icons/bi"
    tag = "BiWinkSmile"


class BiWinkTongue(rx.Component):
    library = "react-icons/bi"
    tag = "BiWinkTongue"


class BiWon(rx.Component):
    library = "react-icons/bi"
    tag = "BiWon"


class BiWorld(rx.Component):
    library = "react-icons/bi"
    tag = "BiWorld"


class BiWrench(rx.Component):
    library = "react-icons/bi"
    tag = "BiWrench"


class BiXCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiXCircle"


class BiX(rx.Component):
    library = "react-icons/bi"
    tag = "BiX"


class BiYen(rx.Component):
    library = "react-icons/bi"
    tag = "BiYen"


class BiZoomIn(rx.Component):
    library = "react-icons/bi"
    tag = "BiZoomIn"


class BiZoomOut(rx.Component):
    library = "react-icons/bi"
    tag = "BiZoomOut"


class BiSolidAddToQueue(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAddToQueue"


class BiSolidAdjustAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAdjustAlt"


class BiSolidAdjust(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAdjust"


class BiSolidAlarmAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAlarmAdd"


class BiSolidAlarmExclamation(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAlarmExclamation"


class BiSolidAlarmOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAlarmOff"


class BiSolidAlarmSnooze(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAlarmSnooze"


class BiSolidAlarm(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAlarm"


class BiSolidAlbum(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAlbum"


class BiSolidAmbulance(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAmbulance"


class BiSolidAnalyse(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAnalyse"


class BiSolidAngry(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAngry"


class BiSolidArch(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArch"


class BiSolidArchiveIn(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArchiveIn"


class BiSolidArchiveOut(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArchiveOut"


class BiSolidArchive(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArchive"


class BiSolidArea(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArea"


class BiSolidArrowFromBottom(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArrowFromBottom"


class BiSolidArrowFromLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArrowFromLeft"


class BiSolidArrowFromRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArrowFromRight"


class BiSolidArrowFromTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArrowFromTop"


class BiSolidArrowToBottom(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArrowToBottom"


class BiSolidArrowToLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArrowToLeft"


class BiSolidArrowToRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArrowToRight"


class BiSolidArrowToTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidArrowToTop"


class BiSolidAward(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidAward"


class BiSolidBabyCarriage(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBabyCarriage"


class BiSolidBackpack(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBackpack"


class BiSolidBadgeCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBadgeCheck"


class BiSolidBadgeDollar(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBadgeDollar"


class BiSolidBadge(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBadge"


class BiSolidBaguette(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBaguette"


class BiSolidBall(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBall"


class BiSolidBalloon(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBalloon"


class BiSolidBandAid(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBandAid"


class BiSolidBank(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBank"


class BiSolidBarChartAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBarChartAlt2"


class BiSolidBarChartSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBarChartSquare"


class BiSolidBarcode(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBarcode"


class BiSolidBaseball(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBaseball"


class BiSolidBasket(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBasket"


class BiSolidBasketball(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBasketball"


class BiSolidBath(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBath"


class BiSolidBatteryCharging(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBatteryCharging"


class BiSolidBatteryFull(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBatteryFull"


class BiSolidBatteryLow(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBatteryLow"


class BiSolidBattery(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBattery"


class BiSolidBed(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBed"


class BiSolidBeenHere(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBeenHere"


class BiSolidBeer(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBeer"


class BiSolidBellMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBellMinus"


class BiSolidBellOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBellOff"


class BiSolidBellPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBellPlus"


class BiSolidBellRing(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBellRing"


class BiSolidBell(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBell"


class BiSolidBible(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBible"


class BiSolidBinoculars(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBinoculars"


class BiSolidBlanket(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBlanket"


class BiSolidBoltCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBoltCircle"


class BiSolidBolt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBolt"


class BiSolidBomb(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBomb"


class BiSolidBone(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBone"


class BiSolidBong(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBong"


class BiSolidBookAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookAdd"


class BiSolidBookAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookAlt"


class BiSolidBookBookmark(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookBookmark"


class BiSolidBookContent(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookContent"


class BiSolidBookHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookHeart"


class BiSolidBookOpen(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookOpen"


class BiSolidBookReader(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookReader"


class BiSolidBook(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBook"


class BiSolidBookmarkAltMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookmarkAltMinus"


class BiSolidBookmarkAltPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookmarkAltPlus"


class BiSolidBookmarkAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookmarkAlt"


class BiSolidBookmarkHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookmarkHeart"


class BiSolidBookmarkMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookmarkMinus"


class BiSolidBookmarkPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookmarkPlus"


class BiSolidBookmarkStar(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookmarkStar"


class BiSolidBookmark(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookmark"


class BiSolidBookmarks(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBookmarks"


class BiSolidBot(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBot"


class BiSolidBowlHot(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBowlHot"


class BiSolidBowlRice(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBowlRice"


class BiSolidBowlingBall(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBowlingBall"


class BiSolidBox(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBox"


class BiSolidBrain(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBrain"


class BiSolidBriefcaseAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBriefcaseAlt2"


class BiSolidBriefcaseAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBriefcaseAlt"


class BiSolidBriefcase(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBriefcase"


class BiSolidBrightnessHalf(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBrightnessHalf"


class BiSolidBrightness(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBrightness"


class BiSolidBrushAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBrushAlt"


class BiSolidBrush(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBrush"


class BiSolidBugAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBugAlt"


class BiSolidBug(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBug"


class BiSolidBuildingHouse(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBuildingHouse"


class BiSolidBuilding(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBuilding"


class BiSolidBuildings(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBuildings"


class BiSolidBulb(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBulb"


class BiSolidBullseye(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBullseye"


class BiSolidBuoy(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBuoy"


class BiSolidBusSchool(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBusSchool"


class BiSolidBus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBus"


class BiSolidBusiness(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidBusiness"


class BiSolidCabinet(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCabinet"


class BiSolidCableCar(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCableCar"


class BiSolidCake(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCake"


class BiSolidCalculator(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalculator"


class BiSolidCalendarAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendarAlt"


class BiSolidCalendarCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendarCheck"


class BiSolidCalendarEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendarEdit"


class BiSolidCalendarEvent(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendarEvent"


class BiSolidCalendarExclamation(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendarExclamation"


class BiSolidCalendarHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendarHeart"


class BiSolidCalendarMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendarMinus"


class BiSolidCalendarPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendarPlus"


class BiSolidCalendarStar(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendarStar"


class BiSolidCalendarWeek(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendarWeek"


class BiSolidCalendarX(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendarX"


class BiSolidCalendar(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCalendar"


class BiSolidCameraHome(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCameraHome"


class BiSolidCameraMovie(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCameraMovie"


class BiSolidCameraOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCameraOff"


class BiSolidCameraPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCameraPlus"


class BiSolidCamera(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCamera"


class BiSolidCapsule(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCapsule"


class BiSolidCaptions(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCaptions"


class BiSolidCarBattery(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCarBattery"


class BiSolidCarCrash(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCarCrash"


class BiSolidCarGarage(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCarGarage"


class BiSolidCarMechanic(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCarMechanic"


class BiSolidCarWash(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCarWash"


class BiSolidCar(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCar"


class BiSolidCard(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCard"


class BiSolidCaretDownCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCaretDownCircle"


class BiSolidCaretDownSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCaretDownSquare"


class BiSolidCaretLeftCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCaretLeftCircle"


class BiSolidCaretLeftSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCaretLeftSquare"


class BiSolidCaretRightCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCaretRightCircle"


class BiSolidCaretRightSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCaretRightSquare"


class BiSolidCaretUpCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCaretUpCircle"


class BiSolidCaretUpSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCaretUpSquare"


class BiSolidCarousel(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCarousel"


class BiSolidCartAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCartAdd"


class BiSolidCartAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCartAlt"


class BiSolidCartDownload(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCartDownload"


class BiSolidCart(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCart"


class BiSolidCastle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCastle"


class BiSolidCat(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCat"


class BiSolidCategoryAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCategoryAlt"


class BiSolidCategory(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCategory"


class BiSolidCctv(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCctv"


class BiSolidCertification(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCertification"


class BiSolidChalkboard(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChalkboard"


class BiSolidChart(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChart"


class BiSolidChat(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChat"


class BiSolidCheckCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCheckCircle"


class BiSolidCheckShield(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCheckShield"


class BiSolidCheckSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCheckSquare"


class BiSolidCheckboxChecked(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCheckboxChecked"


class BiSolidCheckboxMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCheckboxMinus"


class BiSolidCheckbox(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCheckbox"


class BiSolidCheese(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCheese"


class BiSolidChess(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChess"


class BiSolidChevronDownCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronDownCircle"


class BiSolidChevronDownSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronDownSquare"


class BiSolidChevronDown(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronDown"


class BiSolidChevronLeftCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronLeftCircle"


class BiSolidChevronLeftSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronLeftSquare"


class BiSolidChevronLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronLeft"


class BiSolidChevronRightCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronRightCircle"


class BiSolidChevronRightSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronRightSquare"


class BiSolidChevronRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronRight"


class BiSolidChevronUpCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronUpCircle"


class BiSolidChevronUpSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronUpSquare"


class BiSolidChevronUp(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronUp"


class BiSolidChevronsDown(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronsDown"


class BiSolidChevronsLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronsLeft"


class BiSolidChevronsRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronsRight"


class BiSolidChevronsUp(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChevronsUp"


class BiSolidChip(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChip"


class BiSolidChurch(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidChurch"


class BiSolidCircleHalf(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCircleHalf"


class BiSolidCircleQuarter(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCircleQuarter"


class BiSolidCircleThreeQuarter(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCircleThreeQuarter"


class BiSolidCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCircle"


class BiSolidCity(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCity"


class BiSolidClinic(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidClinic"


class BiSolidCloudDownload(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCloudDownload"


class BiSolidCloudLightning(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCloudLightning"


class BiSolidCloudRain(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCloudRain"


class BiSolidCloudUpload(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCloudUpload"


class BiSolidCloud(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCloud"


class BiSolidCoffeeAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCoffeeAlt"


class BiSolidCoffeeBean(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCoffeeBean"


class BiSolidCoffeeTogo(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCoffeeTogo"


class BiSolidCoffee(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCoffee"


class BiSolidCog(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCog"


class BiSolidCoinStack(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCoinStack"


class BiSolidCoin(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCoin"


class BiSolidCollection(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCollection"


class BiSolidColorFill(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidColorFill"


class BiSolidColor(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidColor"


class BiSolidCommentAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCommentAdd"


class BiSolidCommentCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCommentCheck"


class BiSolidCommentDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCommentDetail"


class BiSolidCommentDots(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCommentDots"


class BiSolidCommentEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCommentEdit"


class BiSolidCommentError(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCommentError"


class BiSolidCommentMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCommentMinus"


class BiSolidCommentX(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCommentX"


class BiSolidComment(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidComment"


class BiSolidCompass(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCompass"


class BiSolidComponent(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidComponent"


class BiSolidConfused(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidConfused"


class BiSolidContact(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidContact"


class BiSolidConversation(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidConversation"


class BiSolidCookie(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCookie"


class BiSolidCool(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCool"


class BiSolidCopyAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCopyAlt"


class BiSolidCopy(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCopy"


class BiSolidCopyright(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCopyright"


class BiSolidCoupon(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCoupon"


class BiSolidCreditCardAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCreditCardAlt"


class BiSolidCreditCardFront(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCreditCardFront"


class BiSolidCreditCard(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCreditCard"


class BiSolidCricketBall(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCricketBall"


class BiSolidCrop(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCrop"


class BiSolidCrown(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCrown"


class BiSolidCubeAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCubeAlt"


class BiSolidCube(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCube"


class BiSolidCuboid(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCuboid"


class BiSolidCustomize(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCustomize"


class BiSolidCylinder(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidCylinder"


class BiSolidDashboard(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDashboard"


class BiSolidData(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidData"


class BiSolidDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDetail"


class BiSolidDevices(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDevices"


class BiSolidDiamond(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDiamond"


class BiSolidDice1(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDice1"


class BiSolidDice2(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDice2"


class BiSolidDice3(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDice3"


class BiSolidDice4(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDice4"


class BiSolidDice5(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDice5"


class BiSolidDice6(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDice6"


class BiSolidDirectionLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDirectionLeft"


class BiSolidDirectionRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDirectionRight"


class BiSolidDirections(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDirections"


class BiSolidDisc(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDisc"


class BiSolidDiscount(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDiscount"


class BiSolidDish(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDish"


class BiSolidDislike(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDislike"


class BiSolidDizzy(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDizzy"


class BiSolidDockBottom(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDockBottom"


class BiSolidDockLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDockLeft"


class BiSolidDockRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDockRight"


class BiSolidDockTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDockTop"


class BiSolidDog(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDog"


class BiSolidDollarCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDollarCircle"


class BiSolidDonateBlood(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDonateBlood"


class BiSolidDonateHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDonateHeart"


class BiSolidDoorOpen(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDoorOpen"


class BiSolidDoughnutChart(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDoughnutChart"


class BiSolidDownArrowAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDownArrowAlt"


class BiSolidDownArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDownArrowCircle"


class BiSolidDownArrowSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDownArrowSquare"


class BiSolidDownArrow(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDownArrow"


class BiSolidDownload(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDownload"


class BiSolidDownvote(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDownvote"


class BiSolidDrink(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDrink"


class BiSolidDropletHalf(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDropletHalf"


class BiSolidDroplet(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDroplet"


class BiSolidDryer(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDryer"


class BiSolidDuplicate(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidDuplicate"


class BiSolidEditAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidEditAlt"


class BiSolidEditLocation(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidEditLocation"


class BiSolidEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidEdit"


class BiSolidEject(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidEject"


class BiSolidEnvelopeOpen(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidEnvelopeOpen"


class BiSolidEnvelope(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidEnvelope"


class BiSolidEraser(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidEraser"


class BiSolidErrorAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidErrorAlt"


class BiSolidErrorCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidErrorCircle"


class BiSolidError(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidError"


class BiSolidEvStation(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidEvStation"


class BiSolidExit(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidExit"


class BiSolidExtension(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidExtension"


class BiSolidEyedropper(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidEyedropper"


class BiSolidFaceMask(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFaceMask"


class BiSolidFace(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFace"


class BiSolidFactory(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFactory"


class BiSolidFastForwardCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFastForwardCircle"


class BiSolidFileArchive(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileArchive"


class BiSolidFileBlank(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileBlank"


class BiSolidFileCss(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileCss"


class BiSolidFileDoc(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileDoc"


class BiSolidFileExport(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileExport"


class BiSolidFileFind(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileFind"


class BiSolidFileGif(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileGif"


class BiSolidFileHtml(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileHtml"


class BiSolidFileImage(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileImage"


class BiSolidFileImport(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileImport"


class BiSolidFileJpg(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileJpg"


class BiSolidFileJs(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileJs"


class BiSolidFileJson(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileJson"


class BiSolidFileMd(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileMd"


class BiSolidFilePdf(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFilePdf"


class BiSolidFilePlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFilePlus"


class BiSolidFilePng(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFilePng"


class BiSolidFileTxt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFileTxt"


class BiSolidFile(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFile"


class BiSolidFilm(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFilm"


class BiSolidFilterAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFilterAlt"


class BiSolidFirstAid(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFirstAid"


class BiSolidFlagAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFlagAlt"


class BiSolidFlagCheckered(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFlagCheckered"


class BiSolidFlag(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFlag"


class BiSolidFlame(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFlame"


class BiSolidFlask(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFlask"


class BiSolidFlorist(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFlorist"


class BiSolidFolderMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFolderMinus"


class BiSolidFolderOpen(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFolderOpen"


class BiSolidFolderPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFolderPlus"


class BiSolidFolder(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFolder"


class BiSolidFoodMenu(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFoodMenu"


class BiSolidFridge(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidFridge"


class BiSolidGame(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidGame"


class BiSolidGasPump(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidGasPump"


class BiSolidGhost(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidGhost"


class BiSolidGift(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidGift"


class BiSolidGraduation(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidGraduation"


class BiSolidGridAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidGridAlt"


class BiSolidGrid(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidGrid"


class BiSolidGroup(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidGroup"


class BiSolidGuitarAmp(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidGuitarAmp"


class BiSolidHandDown(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHandDown"


class BiSolidHandLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHandLeft"


class BiSolidHandRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHandRight"


class BiSolidHandUp(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHandUp"


class BiSolidHand(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHand"


class BiSolidHappyAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHappyAlt"


class BiSolidHappyBeaming(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHappyBeaming"


class BiSolidHappyHeartEyes(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHappyHeartEyes"


class BiSolidHappy(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHappy"


class BiSolidHardHat(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHardHat"


class BiSolidHdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHdd"


class BiSolidHeartCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHeartCircle"


class BiSolidHeartSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHeartSquare"


class BiSolidHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHeart"


class BiSolidHelpCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHelpCircle"


class BiSolidHide(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHide"


class BiSolidHomeAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHomeAlt2"


class BiSolidHomeCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHomeCircle"


class BiSolidHomeHeart(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHomeHeart"


class BiSolidHomeSmile(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHomeSmile"


class BiSolidHome(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHome"


class BiSolidHot(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHot"


class BiSolidHotel(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHotel"


class BiSolidHourglassBottom(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHourglassBottom"


class BiSolidHourglassTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHourglassTop"


class BiSolidHourglass(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidHourglass"


class BiSolidIdCard(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidIdCard"


class BiSolidImageAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidImageAdd"


class BiSolidImageAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidImageAlt"


class BiSolidImage(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidImage"


class BiSolidInbox(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidInbox"


class BiSolidInfoCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidInfoCircle"


class BiSolidInfoSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidInfoSquare"


class BiSolidInjection(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidInjection"


class BiSolidInstitution(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidInstitution"


class BiSolidInvader(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidInvader"


class BiSolidJoystickAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidJoystickAlt"


class BiSolidJoystickButton(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidJoystickButton"


class BiSolidJoystick(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidJoystick"


class BiSolidKey(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidKey"


class BiSolidKeyboard(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidKeyboard"


class BiSolidLabel(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLabel"


class BiSolidLandmark(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLandmark"


class BiSolidLandscape(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLandscape"


class BiSolidLaugh(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLaugh"


class BiSolidLayerMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLayerMinus"


class BiSolidLayerPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLayerPlus"


class BiSolidLayer(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLayer"


class BiSolidLayout(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLayout"


class BiSolidLeaf(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLeaf"


class BiSolidLeftArrowAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLeftArrowAlt"


class BiSolidLeftArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLeftArrowCircle"


class BiSolidLeftArrowSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLeftArrowSquare"


class BiSolidLeftArrow(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLeftArrow"


class BiSolidLeftDownArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLeftDownArrowCircle"


class BiSolidLeftTopArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLeftTopArrowCircle"


class BiSolidLemon(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLemon"


class BiSolidLike(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLike"


class BiSolidLocationPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLocationPlus"


class BiSolidLockAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLockAlt"


class BiSolidLockOpenAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLockOpenAlt"


class BiSolidLockOpen(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLockOpen"


class BiSolidLock(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLock"


class BiSolidLogInCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLogInCircle"


class BiSolidLogIn(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLogIn"


class BiSolidLogOutCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLogOutCircle"


class BiSolidLogOut(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLogOut"


class BiSolidLowVision(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidLowVision"


class BiSolidMagicWand(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMagicWand"


class BiSolidMagnet(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMagnet"


class BiSolidMapAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMapAlt"


class BiSolidMapPin(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMapPin"


class BiSolidMap(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMap"


class BiSolidMask(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMask"


class BiSolidMedal(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMedal"


class BiSolidMegaphone(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMegaphone"


class BiSolidMehAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMehAlt"


class BiSolidMehBlank(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMehBlank"


class BiSolidMeh(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMeh"


class BiSolidMemoryCard(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMemoryCard"


class BiSolidMessageAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageAdd"


class BiSolidMessageAltAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageAltAdd"


class BiSolidMessageAltCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageAltCheck"


class BiSolidMessageAltDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageAltDetail"


class BiSolidMessageAltDots(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageAltDots"


class BiSolidMessageAltEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageAltEdit"


class BiSolidMessageAltError(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageAltError"


class BiSolidMessageAltMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageAltMinus"


class BiSolidMessageAltX(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageAltX"


class BiSolidMessageAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageAlt"


class BiSolidMessageCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageCheck"


class BiSolidMessageDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageDetail"


class BiSolidMessageDots(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageDots"


class BiSolidMessageEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageEdit"


class BiSolidMessageError(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageError"


class BiSolidMessageMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageMinus"


class BiSolidMessageRoundedAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageRoundedAdd"


class BiSolidMessageRoundedCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageRoundedCheck"


class BiSolidMessageRoundedDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageRoundedDetail"


class BiSolidMessageRoundedDots(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageRoundedDots"


class BiSolidMessageRoundedEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageRoundedEdit"


class BiSolidMessageRoundedError(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageRoundedError"


class BiSolidMessageRoundedMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageRoundedMinus"


class BiSolidMessageRoundedX(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageRoundedX"


class BiSolidMessageRounded(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageRounded"


class BiSolidMessageSquareAdd(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageSquareAdd"


class BiSolidMessageSquareCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageSquareCheck"


class BiSolidMessageSquareDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageSquareDetail"


class BiSolidMessageSquareDots(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageSquareDots"


class BiSolidMessageSquareEdit(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageSquareEdit"


class BiSolidMessageSquareError(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageSquareError"


class BiSolidMessageSquareMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageSquareMinus"


class BiSolidMessageSquareX(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageSquareX"


class BiSolidMessageSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageSquare"


class BiSolidMessageX(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessageX"


class BiSolidMessage(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMessage"


class BiSolidMeteor(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMeteor"


class BiSolidMicrochip(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMicrochip"


class BiSolidMicrophoneAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMicrophoneAlt"


class BiSolidMicrophoneOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMicrophoneOff"


class BiSolidMicrophone(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMicrophone"


class BiSolidMinusCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMinusCircle"


class BiSolidMinusSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMinusSquare"


class BiSolidMobileVibration(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMobileVibration"


class BiSolidMobile(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMobile"


class BiSolidMoon(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMoon"


class BiSolidMouseAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMouseAlt"


class BiSolidMouse(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMouse"


class BiSolidMoviePlay(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMoviePlay"


class BiSolidMovie(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMovie"


class BiSolidMusic(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidMusic"


class BiSolidNavigation(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidNavigation"


class BiSolidNetworkChart(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidNetworkChart"


class BiSolidNews(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidNews"


class BiSolidNoEntry(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidNoEntry"


class BiSolidNote(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidNote"


class BiSolidNotepad(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidNotepad"


class BiSolidNotificationOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidNotificationOff"


class BiSolidNotification(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidNotification"


class BiSolidObjectsHorizontalCenter(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidObjectsHorizontalCenter"


class BiSolidObjectsHorizontalLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidObjectsHorizontalLeft"


class BiSolidObjectsHorizontalRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidObjectsHorizontalRight"


class BiSolidObjectsVerticalBottom(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidObjectsVerticalBottom"


class BiSolidObjectsVerticalCenter(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidObjectsVerticalCenter"


class BiSolidObjectsVerticalTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidObjectsVerticalTop"


class BiSolidOffer(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidOffer"


class BiSolidPackage(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPackage"


class BiSolidPaintRoll(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPaintRoll"


class BiSolidPaint(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPaint"


class BiSolidPalette(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPalette"


class BiSolidPaperPlane(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPaperPlane"


class BiSolidParking(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidParking"


class BiSolidParty(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidParty"


class BiSolidPaste(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPaste"


class BiSolidPear(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPear"


class BiSolidPen(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPen"


class BiSolidPencil(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPencil"


class BiSolidPhoneCall(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPhoneCall"


class BiSolidPhoneIncoming(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPhoneIncoming"


class BiSolidPhoneOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPhoneOff"


class BiSolidPhoneOutgoing(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPhoneOutgoing"


class BiSolidPhone(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPhone"


class BiSolidPhotoAlbum(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPhotoAlbum"


class BiSolidPiano(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPiano"


class BiSolidPieChartAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPieChartAlt2"


class BiSolidPieChartAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPieChartAlt"


class BiSolidPieChart(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPieChart"


class BiSolidPin(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPin"


class BiSolidPizza(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPizza"


class BiSolidPlaneAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPlaneAlt"


class BiSolidPlaneLand(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPlaneLand"


class BiSolidPlaneTakeOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPlaneTakeOff"


class BiSolidPlane(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPlane"


class BiSolidPlanet(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPlanet"


class BiSolidPlaylist(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPlaylist"


class BiSolidPlug(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPlug"


class BiSolidPlusCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPlusCircle"


class BiSolidPlusSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPlusSquare"


class BiSolidPointer(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPointer"


class BiSolidPolygon(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPolygon"


class BiSolidPopsicle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPopsicle"


class BiSolidPrinter(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPrinter"


class BiSolidPurchaseTagAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPurchaseTagAlt"


class BiSolidPurchaseTag(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPurchaseTag"


class BiSolidPyramid(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidPyramid"


class BiSolidQuoteAltLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidQuoteAltLeft"


class BiSolidQuoteAltRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidQuoteAltRight"


class BiSolidQuoteLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidQuoteLeft"


class BiSolidQuoteRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidQuoteRight"


class BiSolidQuoteSingleLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidQuoteSingleLeft"


class BiSolidQuoteSingleRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidQuoteSingleRight"


class BiSolidRadiation(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRadiation"


class BiSolidRadio(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRadio"


class BiSolidReceipt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidReceipt"


class BiSolidRectangle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRectangle"


class BiSolidRegistered(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRegistered"


class BiSolidRename(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRename"


class BiSolidReport(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidReport"


class BiSolidRewindCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRewindCircle"


class BiSolidRightArrowAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRightArrowAlt"


class BiSolidRightArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRightArrowCircle"


class BiSolidRightArrowSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRightArrowSquare"


class BiSolidRightArrow(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRightArrow"


class BiSolidRightDownArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRightDownArrowCircle"


class BiSolidRightTopArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRightTopArrowCircle"


class BiSolidRocket(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRocket"


class BiSolidRuler(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidRuler"


class BiSolidSad(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSad"


class BiSolidSave(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSave"


class BiSolidSchool(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSchool"


class BiSolidSearchAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSearchAlt2"


class BiSolidSearch(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSearch"


class BiSolidSelectMultiple(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSelectMultiple"


class BiSolidSend(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSend"


class BiSolidServer(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidServer"


class BiSolidShapes(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShapes"


class BiSolidShareAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShareAlt"


class BiSolidShare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShare"


class BiSolidShieldAlt2(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShieldAlt2"


class BiSolidShieldMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShieldMinus"


class BiSolidShieldPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShieldPlus"


class BiSolidShieldX(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShieldX"


class BiSolidShield(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShield"


class BiSolidShip(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShip"


class BiSolidShocked(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShocked"


class BiSolidShoppingBagAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShoppingBagAlt"


class BiSolidShoppingBag(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShoppingBag"


class BiSolidShoppingBags(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShoppingBags"


class BiSolidShow(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShow"


class BiSolidShower(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidShower"


class BiSolidSkipNextCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSkipNextCircle"


class BiSolidSkipPreviousCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSkipPreviousCircle"


class BiSolidSkull(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSkull"


class BiSolidSleepy(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSleepy"


class BiSolidSlideshow(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSlideshow"


class BiSolidSmile(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSmile"


class BiSolidSortAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSortAlt"


class BiSolidSpa(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSpa"


class BiSolidSpeaker(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSpeaker"


class BiSolidSprayCan(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSprayCan"


class BiSolidSpreadsheet(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSpreadsheet"


class BiSolidSquareRounded(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSquareRounded"


class BiSolidSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSquare"


class BiSolidStarHalf(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidStarHalf"


class BiSolidStar(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidStar"


class BiSolidSticker(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSticker"


class BiSolidStopwatch(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidStopwatch"


class BiSolidStoreAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidStoreAlt"


class BiSolidStore(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidStore"


class BiSolidSun(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSun"


class BiSolidSushi(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidSushi"


class BiSolidTShirt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTShirt"


class BiSolidTachometer(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTachometer"


class BiSolidTagAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTagAlt"


class BiSolidTagX(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTagX"


class BiSolidTag(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTag"


class BiSolidTaxi(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTaxi"


class BiSolidTennisBall(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTennisBall"


class BiSolidTerminal(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTerminal"


class BiSolidThermometer(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidThermometer"


class BiSolidTimeFive(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTimeFive"


class BiSolidTime(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTime"


class BiSolidTimer(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTimer"


class BiSolidTired(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTired"


class BiSolidToTop(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidToTop"


class BiSolidToggleLeft(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidToggleLeft"


class BiSolidToggleRight(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidToggleRight"


class BiSolidTone(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTone"


class BiSolidTorch(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTorch"


class BiSolidTrafficBarrier(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTrafficBarrier"


class BiSolidTrafficCone(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTrafficCone"


class BiSolidTraffic(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTraffic"


class BiSolidTrain(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTrain"


class BiSolidTrashAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTrashAlt"


class BiSolidTrash(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTrash"


class BiSolidTreeAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTreeAlt"


class BiSolidTree(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTree"


class BiSolidTrophy(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTrophy"


class BiSolidTruck(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTruck"


class BiSolidTv(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidTv"


class BiSolidUniversalAccess(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUniversalAccess"


class BiSolidUpArrowAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUpArrowAlt"


class BiSolidUpArrowCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUpArrowCircle"


class BiSolidUpArrowSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUpArrowSquare"


class BiSolidUpArrow(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUpArrow"


class BiSolidUpsideDown(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUpsideDown"


class BiSolidUpvote(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUpvote"


class BiSolidUserAccount(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUserAccount"


class BiSolidUserBadge(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUserBadge"


class BiSolidUserCheck(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUserCheck"


class BiSolidUserCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUserCircle"


class BiSolidUserDetail(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUserDetail"


class BiSolidUserMinus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUserMinus"


class BiSolidUserPin(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUserPin"


class BiSolidUserPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUserPlus"


class BiSolidUserRectangle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUserRectangle"


class BiSolidUserVoice(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUserVoice"


class BiSolidUserX(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUserX"


class BiSolidUser(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidUser"


class BiSolidVector(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVector"


class BiSolidVial(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVial"


class BiSolidVideoOff(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVideoOff"


class BiSolidVideoPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVideoPlus"


class BiSolidVideoRecording(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVideoRecording"


class BiSolidVideo(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVideo"


class BiSolidVideos(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVideos"


class BiSolidVirusBlock(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVirusBlock"


class BiSolidVirus(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVirus"


class BiSolidVolumeFull(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVolumeFull"


class BiSolidVolumeLow(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVolumeLow"


class BiSolidVolumeMute(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVolumeMute"


class BiSolidVolume(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidVolume"


class BiSolidWalletAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWalletAlt"


class BiSolidWallet(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWallet"


class BiSolidWasher(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWasher"


class BiSolidWatchAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWatchAlt"


class BiSolidWatch(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWatch"


class BiSolidWebcam(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWebcam"


class BiSolidWidget(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWidget"


class BiSolidWindowAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWindowAlt"


class BiSolidWine(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWine"


class BiSolidWinkSmile(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWinkSmile"


class BiSolidWinkTongue(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWinkTongue"


class BiSolidWrench(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidWrench"


class BiSolidXCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidXCircle"


class BiSolidXSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidXSquare"


class BiSolidYinYang(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidYinYang"


class BiSolidZap(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidZap"


class BiSolidZoomIn(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidZoomIn"


class BiSolidZoomOut(rx.Component):
    library = "react-icons/bi"
    tag = "BiSolidZoomOut"


class BiLogo500Px(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogo500Px"


class BiLogo99Designs(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogo99Designs"


class BiLogoAdobe(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoAdobe"


class BiLogoAirbnb(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoAirbnb"


class BiLogoAlgolia(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoAlgolia"


class BiLogoAmazon(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoAmazon"


class BiLogoAndroid(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoAndroid"


class BiLogoAngular(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoAngular"


class BiLogoApple(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoApple"


class BiLogoAudible(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoAudible"


class BiLogoAws(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoAws"


class BiLogoBaidu(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoBaidu"


class BiLogoBehance(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoBehance"


class BiLogoBing(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoBing"


class BiLogoBitcoin(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoBitcoin"


class BiLogoBlender(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoBlender"


class BiLogoBlogger(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoBlogger"


class BiLogoBootstrap(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoBootstrap"


class BiLogoCPlusPlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoCPlusPlus"


class BiLogoChrome(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoChrome"


class BiLogoCodepen(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoCodepen"


class BiLogoCreativeCommons(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoCreativeCommons"


class BiLogoCss3(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoCss3"


class BiLogoDailymotion(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDailymotion"


class BiLogoDeezer(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDeezer"


class BiLogoDevTo(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDevTo"


class BiLogoDeviantart(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDeviantart"


class BiLogoDigg(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDigg"


class BiLogoDigitalocean(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDigitalocean"


class BiLogoDiscordAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDiscordAlt"


class BiLogoDiscord(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDiscord"


class BiLogoDiscourse(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDiscourse"


class BiLogoDjango(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDjango"


class BiLogoDocker(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDocker"


class BiLogoDribbble(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDribbble"


class BiLogoDropbox(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDropbox"


class BiLogoDrupal(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoDrupal"


class BiLogoEbay(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoEbay"


class BiLogoEdge(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoEdge"


class BiLogoEtsy(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoEtsy"


class BiLogoFacebookCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoFacebookCircle"


class BiLogoFacebookSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoFacebookSquare"


class BiLogoFacebook(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoFacebook"


class BiLogoFigma(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoFigma"


class BiLogoFirebase(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoFirebase"


class BiLogoFirefox(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoFirefox"


class BiLogoFlask(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoFlask"


class BiLogoFlickrSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoFlickrSquare"


class BiLogoFlickr(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoFlickr"


class BiLogoFlutter(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoFlutter"


class BiLogoFoursquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoFoursquare"


class BiLogoGit(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoGit"


class BiLogoGithub(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoGithub"


class BiLogoGitlab(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoGitlab"


class BiLogoGmail(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoGmail"


class BiLogoGoLang(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoGoLang"


class BiLogoGoogleCloud(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoGoogleCloud"


class BiLogoGooglePlusCircle(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoGooglePlusCircle"


class BiLogoGooglePlus(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoGooglePlus"


class BiLogoGoogle(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoGoogle"


class BiLogoGraphql(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoGraphql"


class BiLogoHeroku(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoHeroku"


class BiLogoHtml5(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoHtml5"


class BiLogoImdb(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoImdb"


class BiLogoInstagramAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoInstagramAlt"


class BiLogoInstagram(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoInstagram"


class BiLogoInternetExplorer(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoInternetExplorer"


class BiLogoInvision(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoInvision"


class BiLogoJava(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoJava"


class BiLogoJavascript(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoJavascript"


class BiLogoJoomla(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoJoomla"


class BiLogoJquery(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoJquery"


class BiLogoJsfiddle(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoJsfiddle"


class BiLogoKickstarter(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoKickstarter"


class BiLogoKubernetes(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoKubernetes"


class BiLogoLess(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoLess"


class BiLogoLinkedinSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoLinkedinSquare"


class BiLogoLinkedin(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoLinkedin"


class BiLogoMagento(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMagento"


class BiLogoMailchimp(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMailchimp"


class BiLogoMarkdown(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMarkdown"


class BiLogoMastercard(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMastercard"


class BiLogoMastodon(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMastodon"


class BiLogoMediumOld(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMediumOld"


class BiLogoMediumSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMediumSquare"


class BiLogoMedium(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMedium"


class BiLogoMessenger(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMessenger"


class BiLogoMeta(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMeta"


class BiLogoMicrosoftTeams(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMicrosoftTeams"


class BiLogoMicrosoft(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMicrosoft"


class BiLogoMongodb(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoMongodb"


class BiLogoNetlify(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoNetlify"


class BiLogoNodejs(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoNodejs"


class BiLogoOkRu(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoOkRu"


class BiLogoOpera(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoOpera"


class BiLogoPatreon(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoPatreon"


class BiLogoPaypal(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoPaypal"


class BiLogoPeriscope(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoPeriscope"


class BiLogoPhp(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoPhp"


class BiLogoPinterestAlt(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoPinterestAlt"


class BiLogoPinterest(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoPinterest"


class BiLogoPlayStore(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoPlayStore"


class BiLogoPocket(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoPocket"


class BiLogoPostgresql(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoPostgresql"


class BiLogoProductHunt(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoProductHunt"


class BiLogoPython(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoPython"


class BiLogoQuora(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoQuora"


class BiLogoReact(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoReact"


class BiLogoRedbubble(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoRedbubble"


class BiLogoReddit(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoReddit"


class BiLogoRedux(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoRedux"


class BiLogoSass(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoSass"


class BiLogoShopify(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoShopify"


class BiLogoSketch(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoSketch"


class BiLogoSkype(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoSkype"


class BiLogoSlackOld(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoSlackOld"


class BiLogoSlack(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoSlack"


class BiLogoSnapchat(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoSnapchat"


class BiLogoSoundcloud(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoSoundcloud"


class BiLogoSpotify(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoSpotify"


class BiLogoSpringBoot(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoSpringBoot"


class BiLogoSquarespace(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoSquarespace"


class BiLogoStackOverflow(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoStackOverflow"


class BiLogoSteam(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoSteam"


class BiLogoStripe(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoStripe"


class BiLogoTailwindCss(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoTailwindCss"


class BiLogoTelegram(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoTelegram"


class BiLogoTiktok(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoTiktok"


class BiLogoTrello(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoTrello"


class BiLogoTripAdvisor(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoTripAdvisor"


class BiLogoTumblr(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoTumblr"


class BiLogoTux(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoTux"


class BiLogoTwitch(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoTwitch"


class BiLogoTwitter(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoTwitter"


class BiLogoTypescript(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoTypescript"


class BiLogoUnity(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoUnity"


class BiLogoUnsplash(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoUnsplash"


class BiLogoUpwork(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoUpwork"


class BiLogoVenmo(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoVenmo"


class BiLogoVimeo(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoVimeo"


class BiLogoVisa(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoVisa"


class BiLogoVisualStudio(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoVisualStudio"


class BiLogoVk(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoVk"


class BiLogoVuejs(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoVuejs"


class BiLogoWhatsappSquare(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoWhatsappSquare"


class BiLogoWhatsapp(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoWhatsapp"


class BiLogoWikipedia(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoWikipedia"


class BiLogoWindows(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoWindows"


class BiLogoWix(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoWix"


class BiLogoWordpress(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoWordpress"


class BiLogoXing(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoXing"


class BiLogoYahoo(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoYahoo"


class BiLogoYelp(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoYelp"


class BiLogoYoutube(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoYoutube"


class BiLogoZoom(rx.Component):
    library = "react-icons/bi"
    tag = "BiLogoZoom"


